package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@$!`0````````````(`"``!````4!9``#0```#8R@``!Q```#0`(``)
M`"@`'P`>``8````T````-`!``#0`0``@`0``(`$```4````$`````P```%0!
M``!4`4``5`%```T````-````!`````$```````!PA`$``(0!0`"$`4``&```
M`!@````$````!`````$```````````!`````0``$Q```!,0```4```````$`
M`0````3$```$Q$$`!,1!`/0!```L$@``!@```````0`"````P`$``,`!0`#`
M`4````$````!```'````!`````0```!D`0``9`%``&0!0``@````(`````0`
M```$````!````)P!``"<`4``G`%``"0````D````!`````0`````````````
M````````````````````````````!````"]L:6(O;&0N<V\N,0`````$````
M$`````$```!'3E4```````(````&````$@```/8!`+(`````````````````
M````8$1"``0````4`````P```$=.50#?@2P!]*B:UN[^<.+21*4XR@+,X`$`
M```.!````0```$\$```!````6@0```$```!D!````0```(8$```!````J00`
M``P```#`%4``#0```-!C0``$````P`)```4```#\#4``!@```#P&0``*````
M2@8```L````0````%@``<&#$00`5``````````,```!PQ$$``0``<`$````%
M``!P`@````8``'```$``"@``<`@````1``!P?````!(``'`>````$P``<",`
M``#^__]O0!5``/___V\"````\/__;T840```````````````````````````
M``````````````````````````````````````!A````?````&\`````````
M`````#``````````*P```"P`````````*````&(````U````.@```"<```!X
M````$`````````!#````)@````,```!"````'P````H```!W````2@``````
M````````3````!H```!<```````````````(````*@````\```!Q````&P``
M`"(````E````>@```",`````````6@`````````O````/@```!X````9````
M``````L````3````3@`````````Y```````````````8````<@```#,````M
M``````````````!G`````````#0``````````@```%8`````````7@```$0`
M``!N````00```$T```!'``````````````!U````!````#<````=````)```
M`#@````_`````````!$````7``````````````!)````%@`````````N````
M"0```#$````V````3P```'L`````````````````````````````````````
M````````````````````!P````````````````````````!D`````````&T`
M``!Y``````````````!9```````````````2````/````%``````````````
M`$L````<`````````$@````]````!@```'0````I````.P````4`````````
M`````"$````@`````````$8```!``````````!4````R``````````````!P
M````8`````````!8````#@```!0```!=````;````%(```!%````````````
M``!3````=@```%$```!5`````````%\`````````````````````````````
M`&D```````````````P`````````5````&,`````````6P````````!7````
M`````````````````````&$``````````0```&@``````````````&8`````
M```````````````-````90```&H`````````:P``````````````````````
M````````<P``````````````````````````````````````````````````
M`````````````````````````````````````````````````'D%```@Q$$`
M`````"$`%0#8!```^,5!```````0`/'_XP0``.@W0``(````$@`,`/0$``"0
M%T``4````!(`#``!!0``8$1"```````3`/'_'@0```$`````````$P#Q_QL`
M``#08T```````!(`#@`*!0``3%5``$`'```2``P`(`4``,`K0`!X````$@`,
M`"X%```,-T``W````!(`#``Y!```<,1!```````1`/'_1`4``.0^0`#,`0``
M$@`,`%`%``",/D``6````!(`#`!K!0``L$!``.`````2``P`D`0``"!D0``$
M````$0`/`'<%```@Q$$``````!$`%0"?!0``8$1"```````0`/'_A`4``(Q<
M0`!H````$@`,`(P%``!0%D```````!(`#`"^!```(,1!```````0`!4`E`4`
M````````````$0```,P$``#XQ4$``````!``\?^W!```4!9````````0``P`
MHP4``%#$00`$````$0`5`+<%```(+D``J````!(`#`#>!```,-9!```````0
M`/'_TP4``$#$00`$````$0`5`"\$``!@Q$$``````!$`%@"?!```````````
M```1````YP4``%Q(0`#P#```$@`,`,4$``#XQ4$``````!``\?_T!0``U#I`
M`-0!```2``P`!@8``'A%0`#D`@``$@`,`!,&``"H/$``Y`$``!(`#`">`P``
ML&-````````2````OP```*!C0```````$@```(8%``#`%4```````!(`"P`N
M````D$%``.@#```2``P`X@(``)!C0```````$@```.$!``"`8T```````!(`
M``"P`P``<&-````````2````$@,``&!C0```````$@```(`"``!08T``````
M`!(```!N````0&-````````2````\@$``#!C0```````$@```/(#```@8T``
M`````!(```#G`@`````````````1````/@$``!!C0```````$@```"T#````
M8T```````!(```!6````\&)````````2````9P```.!B0```````$@````P!
M``#08D```````!(```"5`@``P&)````````2````8@(``+!B0```````$@``
M`/8"``"@8D```````!(```#+`0``D&)````````2````7@```(!B0```````
M$@```)$!``!P8D```````!(````M`0``8&)````````2````"P,``%!B0```
M````$@```(L!``!`8D```````!(````4`@``L%U``#@````2`@P`SP,``#!B
M0```````$@```*$"```@8D```````!(```#3`0``$&)````````2````3`,`
M``!B0```````$@```+,"``#P84```````!(```!A`P``X&%````````2````
M@@$``-!A0```````$@```)`#``#`84```````!(```"A!``````````````1
M````V@$``+!A0```````$@````$```#X74``L````!(`#`"4````H&%`````
M```2````8@4``)!A0```````$@```'L!``"`84```````!(```!B`0``<&%`
M```````2````VP,``&!A0```````$@```+P!``!084```````!(```!%`P``
M```````````1````6`$``$!A0```````$@```%,"```P84```````!(```#]
M`P``(&%````````2````(P(`````````````$@```.(#`````````````!(`
M```9`P``$&%````````2````RP(```!A0```````$@```%`!``#P8$``````
M`!(```!N`P``X&!````````2````K@$``-!@0```````$@```*@%```0:$``
MZEL``!$`#P"C`0``P&!````````2````L0```+!@0```````$@```,8"``"@
M8$```````!(````T`@``D&!````````2````2`(``(!@0```````$@```%P#
M``!P8$```````!(```"`````8&!````````2````(0```%!@0```````$@``
M`*,```!`8$```````!(```!G`P``,&!````````2````@`,``"!@0```````
M$@```,$#```08$```````!(```#9`@```&!````````2````5`,``/!?0```
M````$@```'0$``#@7T```````!(```#J`0``T%]````````2````_P```,!?
M0```````$@```.T```"P7T```````!(```!Q`0``H%]````````2````&0$`
M`)!?0```````$@```,,!``"`7T```````!(```!"```````````````@````
M,P``````````````(@````$"`````````````!(```"H`@``<%]````````2
M````$0```/!=0``(````$@`,`,$"``!@7T```````!(````G`P``4%]`````
M```2````M0$``$!?0```````$@```-8````P7T```````!(```!I`0``(%]`
M```````2````-`,``!!?0```````$@````!?7VQI8F-?8W-U7VEN:70`7U]L
M:6)C7V-S=5]F:6YI`%]?;&EB8U]S=&%R=%]M86EN`%]?9VUO;E]S=&%R=%]?
M`%]*=E]296=I<W1E<D-L87-S97,`<W1R;F-M<`!R96%D;&EN:P!M96UC:'(`
M4&5R;%]'=&AR7VME>5]P='(`<'1H<F5A9%]G971S<&5C:69I8P!097)L7W-V
M7W-E='!V;@!097)L7W-V7W-E='!V`%!E<FQ?9&]U;G=I;F0`4&5R;%]S879E
M7V1E<W1R=6-T;W)?>`!097)L7TEC=7)S=&%C:VEN9F]?<'1R`%!E<FQ?26EN
M7V5V86Q?<'1R`%!E<FQ?26]P7W!T<@!097)L7VYE=U-6<'8`4&5R;%])979A
M;%]R;V]T7W!T<@!097)L7TEP87)S97)?<'1R`%!E<FQ?271O<%]E;G9?<'1R
M`&]P96YD:7(`<F5A9&1I<C8T`'-T<FQE;@!S<')I;G1F`%]?>'-T870V-`!U
M;FQI;FL`8VQO<V5D:7(`<FUD:7(`4&5R;%])<W1A=&)U9E]P='(`7U]L>'-T
M870V-`!A8V-E<W,`9V5T<&ED`&UE;6-P>0!R96%L;&]C`&UE;6UO=F4`<W1R
M<W1R`&=E='5I9`!?7W-T<F1U<`!S=')N8W!Y`%!E<FQ?<WES7VEN:70S`%!E
M<FQ?871F;W)K7W5N;&]C:P!P=&AR96%D7V%T9F]R:P!097)L7V%T9F]R:U]L
M;V-K`%!E<FQ?1V1O7W5N9'5M<%]P='(`<&5R;%]A;&QO8P!P97)L7V-O;G-T
M<G5C=`!097)L7TEP97)L7V1E<W1R=6-T7VQE=F5L7W!T<@!097)L7TEE>&ET
M7V9L86=S7W!T<@!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]P87)S90!P97)L
M7V1E<W1R=6-T`'!E<FQ?9G)E90!097)L7W-Y<U]T97)M`'!E<FQ?<G5N`&5X
M:70`4$Q?;65M;W)Y7W=R87``4&5R;%]C<F]A:U]N;V-O;G1E>'0`<W1R=&]K
M`'-T<F-M<`!?7V-T>7!E7V)?;&]C`&UK9&ER`&]P96XV-`!?7V5R<FYO7VQO
M8V%T:6]N`'-T9&5R<@!F<')I;G1F`&QS965K-C0`<F5A9`!C;&]S90!M96US
M970`4&5R;%])=&%I;G1E9%]P='(`4&5R;%]G=E]F971C:'!V`%!E<FQ?879?
M9F5T8V@`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%])8V]M<&-V7W!T<@!097)L
M7V%V7W-H:69T`%!E<FQ?;6=?<V5T`&5X96-V<`!B;V]T7T1Y;F%,;V%D97(`
M4&5R;%]N97=84P!097)L7VYE=UA37V9L86=S`&QI8G!E<FPN<V\N-2XQ,`!?
M1%E.04U)0U],24Y+24Y'`%]?4DQ$7TU!4`!?1TQ/0D%,7T]&1E-%5%]404),
M15\`;&EB9&PN<V\N,@!L:6)M+G-O+C8`;&EB<'1H<F5A9"YS;RXP`%]?<F5G
M:7-T97)?871F;W)K`&QI8F,N<V\N-@!?24]?<W1D:6Y?=7-E9`!?7V5N=FER
M;VX`;&EB8W)Y<'0N<V\N,0!?9G1E>'0`7V9D871A`%]E9&%T80!?7V)S<U]S
M=&%R=`!?9F)S<P!?96YD`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A<V5N86UE
M`%]G<%]D:7-P`%A37TEN=&5R;F%L<U]005)?0D]/5`!P87)?96YV7V-L96%N
M`'!A<E]C=7)R96YT7V5X96-?<')O8P!P87)?9&ER;F%M90!G971?=7-E<FYA
M;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?7V1A=&%?<W1A<G0`>'-?
M:6YI=`!?7W-T87)T`%]?9VYU7VQO8V%L7V=P`&YA;65?;&]A9%]M>5]P87)?
M<&P`6%-?26YT97)N86QS7U!!4E]#3$5!4E-404-+`'-I>F5?;&]A9%]M>5]P
M87)?<&P`<&%R7VUK=&UP9&ER`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD
M<')O9P!P87)?:6YI=%]E;G8`1TQ)0D-?,BXS`$=,24)#7S(N,RXR`$=,24)#
M7S(N,@!'3$E"0U\R+C`````!``$``0`!`````0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$````!``$``0`!``$``0`!``,``0`!``$``0`!```````!
M``$``P`#`````P`````````````````&``,``P````````````,``P``````
M`P`#``$````#``,``P````(``P````,``P`!`````P`#``,``P`#``,`!```
M``````````<````#`````P`!``0````#```````"``(``P````,`````````
M!@`%``,```````0````#`````````````0````,``P````,``@````$`!`"&
M!```$````%`````3:6D-```'`"`&```0````<AEI"0``!0`J!@``$````!)I
M:0T```0`-@8``!`````0:6D-```#`$`&`````````0`"`&0$```0````````
M`!)I:0T```8`-@8``!`````0:6D-```"`$`&`````````@`</*`NG"<AX)D#
MX/^])QP`OZ\0`+RO;(&"CR4((``%`$`0)0@@`&R!F8\E""``"?@@`R4((``!
M`!$$)0@@`$(`'#Q@1)PG&("9CR4((`!4%SDG3P`1!"4((``!`!$$)0@@`$(`
M'#Q@1)PG&("9CR4((`"P7CDG'1(1!"4((``<`+^/)0@@``@`X`,@`+TG(0#@
M`P$`$00E""``0@`</&!$G"<A^```/("$CP``I8\$`*8G^/\!)"3HH0/@_[TG
MR("'CWB!B(\E""``$`"HKQ0`HJ\8`+VO,(&9CR4((``)^"`#)0@@`/__`!`E
M""``T/^])R@`LZ]"`!,\`,9BDBP`OZ\D`+*O(`"QKQH`0!0<`+"O0@`2/$(`
M$3P,Q%(F$,0Q)B.(,@)"`!`\@X@1``3&`H[__S$F*QA1``P`8!`!`$(D@!@"
M`"$80P(``'F,)0@@``GX(`,$Q@*N!,8"CB4((``K&%$`]O]@%`$`0B0!``(D
M`,9BHBP`OX\H`+./)`"RCR``L8\<`+"/"`#@`S``O2="``0\%,2"C$(`'#P'
M`$`08$2<)VB!F8\E""```P`@$R4((``(`"`#%,2$)`@`X`,E""``)0@@`"4(
M(````(.`)0@@``\`8!!"``4\&,2EC"$0@````*6``0"$)`<`91`E""````"#
M@"4((`#[_V`4`0"$)`@`X`,E""``^?\`$"$0@``(`.`#(1"``+C^O2<(`*,G
M'`"%)"$X8`!(`*LG_P`*/```HHPE""```DX"```V`@``0@(`)3`F`21`"@$"
M$@(`)3#(``#_0C`E$,(```!BK`0`8R3R_VL4!`"E)#0!YR0\`*(G[/]%C```
M0XS4_T:,)ABC`,S_18PF&&8`)AAE`$`H`P#"'P,`)1AE``P`0ZP$`$(D\_]'
M%"4((``(`**/$`"'C```@XP$`(6,"`"(C`P`AHPA..(`@EH"/)EY0C1`20,`
MPF8#`"=8!0`D4`4!)6")`2189@$A..(`@$\%`((H!0`E2"4!(3CL`"4H:@$A
M..4`#`"ECR=8`P`A,,4`)%AH`20H(P$E6&4!PE8'`"$PP@!`*0<`)2A%`2$P
MRP`A,,4`$`"MCX(H`P"`5P,`)5!%`4!9!@#"9@8`)R@'`"5@BP$A0`T!)%CJ
M`"0HJ0`A:`(!)2BK`(!'!P`4`*N/@C@'`"5`!P$A.*P!)V`&`"$HY0`A6&(!
M)#C(`"1@B@$E8(<!(4AI`<(^!0!`604`(4@L`1@`K8\E..L`(3@G`8!/!@""
M,`8`)4@F`4!9!P`A:*(!PC8'`"=@!0`A:*H!)&"(`24PRP"`5P4`)%BI`((H
M!0`E4$4!)2B+`1P`JX\A,*8!)V`'`"$PQ0`A6&(!)"CJ`"1@B0$E8(4!(4!H
M`<(N!@!`608`(4`,`2``K8\E**L`(2@%`8!'!P"".`<`)4`'`4!9!0`A:*(!
MPCX%`"=@!@`A:*D!)&"*`24XZP"`3P8`)%C(`((P!@`E2"8!)3"+`20`JX\A
M.*<!)V`%`"$XY@`A6&(!)#"I`"1@B`$E8(8!(5!J`<(V!P!`60<`(5!,`24P
MRP`A,$8!*`"MCX!7!0""*`4`)5!%`4!9!@#"9@8`)R@'`"5@BP$A:*(!)%CJ
M`"0HJ0`A:*@!)2BK`(!'!P`L`*N/@C@'`"5`!P$A.*P!)V`&`"$HY0`A6&(!
M)#C(`"1@B@$E8(<!(4AI`<(^!0!`604`(4@L`3``K8\E..L`(3@G`8!/!@""
M,`8`)4@F`4!9!P`A:*(!PC8'`"=@!0`A:*H!)&"(`24PRP"`5P4`)%BI`((H
M!0`E4$4!)2B+`30`JX\A,*8!)V`'`"$PQ0`A6&(!)"CJ`"1@B0$E8(4!(4!H
M`<(N!@!`608`(4`,`3@`K8\E**L`(2@%`8!'!P"".`<`)4`'`4!9!0`A:*(!
MPCX%`"=@!@`A:*D!)&"*`24XZP"`3P8`)%C(`((P!@`E2"8!)3"+`3P`JX\A
M.*<!)V`%`"$XY@`A6&(!)#"I`"1@B`$E8(8!(5!J`<(V!P!`60<`(5!,`24P
MRP`A,$8!0`"MCX!7!0""*`4`)5!%`4!9!@#"9@8`)R@'`"5@BP$A:*(!)%CJ
M`"0HJ0`A:*@!)2BK`(!'!P!$`*N/@C@'`"5`!P$A.*P!)V`&`"$HY0`A6&(!
M)#C(`"1@B@$E8(<!(4AI`<(^!0!`604`(4@L`4@`K8\E..L`(3@G`8!/!@""
M,`8`)4@F`4!9!P`A:*(!PC8'`"=@!0`A:*H!)&"(`24PRP"`5P4`)%BI`((H
M!0`E4$4!)2B+`4P`JX\A,*8!)V`'`"$PQ0`A6&(!)"CJ`"1@B0$E8(4!(4!H
M`<(N!@!`608`(4`,`24HJP!0`*N/(2@%`8!'!P"".`<`)4`'`2%88@%`.04`
MPFX%`"=@!@`E:*<!)&"*`2%(:0&`/P8`)%C(`((P!@`E..8`(4@M`24PBP$A
M2"8!5`"FCR=H!0`A$,(`)&BH`20PIP`E:*8!(5!*`,)F"0!`60D`(5!-`8`W
M!0!8`*V/@B@%`-EN`CRAZT(T)3#%`"4HBP$A*$4!(6BB`290QP`A:*@!)E!)
M`<)F!0!`604`@$<)`"%0J@&"2`D`7`"MCR5`"0$E2(L!(5!)`2%HH@$F2`8!
M(6BG`<)F"@!`60H`)D@E`8`_!0""*`4`)3CE`"%(J0$E*(L!(4@E`6``I8\F
M:.@`(2BB`"9HJ@$A,*8`PF8)`$!9"0"`+PH`(3#-`()0"@!D`*V/)2BJ`"50
MBP$A,,H`(6BB`290IP`A:*@!)E!)`<)F!@!`608`@$<)`"%0J@&"2`D`:`"M
MCR5`"0$E2(L!(5!)`2%HH@$F2`4!(6BG`29()@&`/P8`(4BI`8(P!@!L`*V/
M)3CF`,)F"@!`60H`)3"+`2%HH@$F8.@`(4@F`2%HI0$F8(H!@"\*`()0"@`E
M**H`0%D)`"%0K`'"-@D`<`"MCR4PRP`A,$8!(6BB`290IP`A:*@!)E!)`<)F
M!@!`608`@$<)`"%0J@&"2`D`=`"MCR5`"0$E2(L!(5!)`2%HH@$F2`4!(6BG
M`29()@&`/P8`(4BI`8(P!@!X`*V/)3CF`,)F"@!`60H`)3"+`2%HH@$F8.@`
M(4@F`2%HI0$F8(H!@"\*`()0"@`E**H`0%D)`"%0K`'"-@D`?`"MCR4PRP`A
M,$8!(6BB`290IP`A:*@!)E!)`<)F!@!`608`@$<)`"%0J@&"2`D`@`"MCR5`
M"0$E2(L!(5!)`2%HH@$F2`4!(6BG`29()@&`/P8`(4BI`8(P!@"$`*V/)3CF
M`,)F"@!`60H`)3"+`2%HH@$F8.@`(4@F`2%HI0$F8(H!@"\*`()0"@`E**H`
M0%D)`"%0K`'"-@D`B`"MCR4PRP`A,$8!(6BB`290IP`A:*@!)E!)`<)F!@!`
M608`@$<)`"%0J@&"2`D`C`"MCR5`"0$E2(L!(5!)`2%HH@$F2`4!(6BG`29(
M)@&`/P8`(4BI`8(P!@"0`*V/)3CF`,)F"@!`60H`)3"+`2%HH@$F8.@`(4@F
M`2%HI0$F8(H!@"\*`()0"@`E**H`0%D)`"%0K`'"-@D`E`"MCR4PRP`A,$8!
M(6BB`290IP`A:*@!PF8&`$!9!@`F4$D!@$<)`()("0`E0`D!(5"J`25(BP$A
M4$D!F`"ICR9H!0$A2"(!)FBF`2$X)P$A..T`@$\&`)P`K8^",`8`)4@F`<)F
M"@!`60H`)3"+`2%HH@$F8"@!(3CF`"%HI0$F8(H!@"\*`()0"@`E**H`0%D'
M`"%0K`'"-@<`H`"MCR4PRP`A,$8!(6BB`290J0`A:*@!PF8&`$!9!@`F4$<!
M@$<'`((X!P`E0`<!(5"J`24XBP$A4$<!I`"GCR98!0$A$.(`@F`&`(`_!@`E
M..P`)C!F`<)F"@"H`*V/(4A)`$!9"@`;CP(\W+Q"-"58BP$A2"8!)6#H`"%(
M*P$A:*(!)%CH`"1@B@&`-PH`@E`*`"4PR@`E8(L!(2BE`4!9"0"L`*V/PE8)
M`"$HK``E4$L!)6#'`"%0J@`D6,<`(6BB`21@B0&`+PD`@D@)`"4HJ0`E8(L!
M(4"H`4!9"@"P`*V/PDX*`"%`#`$E2"L!)6"F`"%("0$D6*8`(6BB`21@B@&`
M1PH`@E`*`"5`"@$E8(L!(3BG`4!9"0"T`*V/PE8)`"$X[``E4$L!)6`%`2%0
MZ@`D6`4!(6BB`21@B0&`/PD`@D@)`"4XZ0`E8(L!(3"F`4!9"@"X`*V/PDX*
M`"$PS``E2"L!)6#H`"%(R0`D6.@`(6BB`21@B@&`-PH`@E`*`"4PR@`E8(L!
M(2BE`4!9"0"\`*V/PE8)`"$HK``E4$L!)6#'`"%0J@`D6,<`(6BB`21@B0&`
M+PD`@D@)`"4HJ0`E8(L!(4"H`4!9"@#``*V/PDX*`"%`#`$E2"L!)6"F`"%(
M"0$D6*8`(6BB`21@B@&`1PH`@E`*`"5`"@$E8(L!(3BG`4!9"0#$`*V/PE8)
M`"$X[``E4$L!)6`%`2%0Z@`D6`4!(6BB`21@B0&`/PD`@D@)`"4XZ0`E8(L!
M(3"F`4!9"@#(`*V/PDX*`"$PS``E2"L!)6#H`"%(R0`D6.@`(6BB`21@B@&`
M-PH`@E`*`"4PR@`E8(L!(2BE`4!9"0#,`*V/PE8)`"$HK``E4$L!)6#'`"%0
MJ@`D6,<`(6BB`21@B0&`+PD`@D@)`"4HJ0`E8(L!(4"H`4!9"@#0`*V/PDX*
M`"%`#`$E2"L!)6"F`"%("0$D6*8`(6BB`21@B@&`1PH`@E`*`"5`"@$E8(L!
M(3BG`4!9"0#4`*V/PE8)`"$X[``E4$L!)6`%`2%0Z@`D6`4!(6BB`21@B0&`
M/PD`@D@)`"4XZ0`E8(L!(3"F`4!9"@#8`*V/PDX*`"$PS``E2"L!)6#H`"%(
MR0`D6.@`(6BB`21@B@&`-PH`@E`*`"4PR@`E8(L!(2BE`4!9"0#<`*V/PE8)
M`"$HK``E4$L!)6#'`"%0J@`D6,<`(6BB`21@B0&`+PD`@D@)`"4HJ0`E8(L!
M(4"H`4!9"@#@`*V/PDX*`"%`#`$E2"L!)6"F`"%("0$D6*8`(6BB`21@B@&`
M1PH`@E`*`"5`"@$E8(L!(3BG`4!9"0#D`*V/PE8)`"$X[``E4$L!)6`%`2%0
MZ@`D6`4!(6BB`21@B0&`/PD`@D@)`"4XZ0`E8(L!(3"F`4!9"@#H`*V/PDX*
M`"$PS``E2"L!)6#H`"%(R0`D6.@`(6BB`21@B@&`-PH`@E`*`"4PR@`E8(L!
M(2BE`4!9"0#L`*V/PE8)`"$HK``E4$L!)6#'`"%0J@`D6,<`(6BB`21@B0&`
M+PD`@D@)`"4HJ0`E8(L!(4"H`4!9"@#P`*V/PDX*`"%`#`$E2"L!)6"F`"%(
M"0$D6*8`(6BB`21@B@&`1PH`@E`*`"5`"@$E8(L!(3BG`<)>"0!`40D`)5!J
M`2$X[``A..H`]`"JCR5H!0$A$$(!)&BI`210!0$E:*H!PF8'`$!1!P`A,$8`
M@%\)`()("0`E6&D!(3#-`"5(B@$A,,D`8LH"//@`J8_6P4(T(4@B`290:`$A
M*"4!)E!'`<)N!@!`808`@$\'`"%0J@"".`<`_`"ECR5()P$E.*P!(5!'`2$H
MH@`F:"L!)FBF`<)F"@`A0*@`0"D*`"4HA0$A0`T!(4`%`8`_!@```:6/@C`&
M`"4XY@`A**(`)FCI`"9HJ@$A6*L`(5AM`8`O"@`$`:V/@E`*`"4HJ@!`80@`
MPC8(`"90IP`E,,P`(6BB`2$P9@$A:*D!)E!(`<)F!@!`608`@$\(`"%0J@&"
M0`@`"`&MCR5(*`$E0(L!(5!(`2%HH@$F0"4!(6BG`29`!@&`/P8`(4"H`8(P
M!@`,`:V/)3CF`,)F"@!`60H`)3"+`2%HH@$F8.D`(4`&`2%HI0$F8(H!@"\*
M`()0"@`E**H`0%D(`"%0K`'"-@@`$`&MCR4PRP`A,$8!(6BB`290IP`A:*D!
M)E!(`<)F!@!`608`@$\(`"%0J@&"0`@`%`&MCR5(*`$E0(L!(5!(`2%HH@$F
M0"4!(6BG`29`!@&`/P8`(4"H`8(P!@`8`:V/)3CF`,)F"@!`60H`)3"+`2%H
MH@$F8.D`(4`&`2%HI0$F8(H!@"\*`()0"@`E**H`0%D(`"%0K`'"-@@`'`&M
MCR4PRP`A,$8!(6BB`290IP`A:*D!)E!(`<)F!@!`608`@$\(`"%0J@&"0`@`
M(`&MCR5(*`$E0(L!(5!(`2%HH@$F0"4!(6BG`29`!@&`/P8`(4"H`8(P!@`D
M`:V/)3CF`,)F"@!`60H`)3"+`2%HH@$F8.D`(4`&`2%HI0$F8(H!@"\*`()0
M"@`E**H`0%D(`"%0K`'"-@@`*`&MCR4PRP`A,$8!(6BB`290IP`A:*D!)E!(
M`<)F!@!`608`@$\(`"%0J@&"0`@`+`&MCR5(*`$E0(L!(5!(`2%HH@$F0"4!
M(6BG`29`!@&`/P8`(4"H`8(P!@`P`:V/)3CF`,)F"@!`60H`)3"+`2%HH@$F
M8.D`(4`&`2%HI0$F8(H!@"\*`()0"@`E**H`0%D(`"%0K`'"-@@`-`&MCR4P
MRP`A,$8!(6BB`290IP`A:*D!)E!(`<)F!@!`608`@$\(`"%0J@&"0`@`.`&M
MCR5(*`$E0(L!(5!(`2%HH@$F0"4!(6BG`29`!@'"9@H`0%D*`(`_!@`A0*@!
M@C`&`#P!K8\E..8`)3"+`2%`!@$F8.D`(6BB`2%HI0$F8(H!0%D(`(`O"@#"
M-@@`@E`*`"4HJ@`E,,L`(5"L`2$P1@%``:J/)FBG`"%00@$F:*@!PF8&`$!9
M!@`A2$D!@%<(`()`"``E4$@!)4"+`40!JX\A2"T!(1AK`"%`*`$A$&(`)DA%
M`29()@%`&0@`(3A'`,(6"``A..D`)1!#`"$0X@```(*L@%\&``0`B8P(`(*,
M#`"'C!``@XR",`8`)3#+`"%`*`$A$$8`(5#J`"$H90`0`(6L!`"(K`@`@JP,
M`(JL"`#@`T@!O2="`!P\R/^])V!$G"<T`+^O,`"VKRP`M:\H`+2O)`"SKR``
MLJ\<`+&O&`"PKQ``O*\AD(``#`"`%"&PH``A$```-`"_CS``MH\L`+6/*`"T
MCR0`LX\@`+*/'`"QCQ@`L(\(`.`#.`"])\"`@H\E""````!5C"4((`#Q_Z`2
M(1``````@H`E""``#0!`$"&8```]``,D"@!#$"4((``AF(```0!S)@``8H(E
M""```P!`$"4((`#Z_T,4)0@@`".8<@(``+".)0@@`-S_`!(AB*`"/0`4)&R`
MF8\A(``"(2A``@GX(`,A,&`"$`"\CP4`0!0A&!,"``!B@"4((``(`%00)0@@
M``0`,28``#".)0@@`/#_`!8A$```R?\`$"4((``CB#4"@X@1``$`<R8``-&N
MP_\`$"$0$P+8_[TG)`"_KYH*$`P8`*4G)`"_CR4((``(`.`#*`"])^#_O2<8
M`+"O0@`0/##$`H[__P,D!0!#$!P`OZ\<`+^/&`"PCP@`X`,@`+TG0``$/.@*
M$`PD9(0D#`!`$"4((````$*`)0@@``@`0!`E""``,`!"."L0`@`PQ`*N'`"_
MCQ@`L(\(`.`#(`"])R$0``#Z_P`0,,0"KD(`'#S0_[TG8$2<)RP`OZ\H`+*O
M)`"QKR``L*\0`+RO(8B``,"`DH\*```0&`"P)Q@`HH\``$..@!`"`"$08@`$
M`$(D``!#C"4((`#\_V`4_/]#K"$@(`*:"A`,(2@``O/_0!0E""``+`"_CR@`
MLH\D`+&/(`"PCP@`X`,P`+TG0@`</-#OO2=@1)PG+!"_KR@0LZ\D$+*O(!"Q
MKQP0L*\0`+ROB("9CQ@`L"=```0\(9"@`"&8P``P9(0D(2@``@GX(`/_#P8D
M$`"\CRD`0!C__U$D(1@1`@``8X`E""``(@!@$"4((``AB$``<("9CR$@``(O
M``4D"?@@`R$P(`(0`+R/&P!`$"4((`!4@)F/)0@@``GX(`,A(```$`"\CP``
M1(PL@9F/)0@@``GX(`,E""``$`"\CR$H0`+,@)F/(3```B$X(`()^"`#(2!`
M`"P0OX\H$+./)!"RCR`0L8\<$+"/"`#@`S`0O2??_R`6)0@@`%2`F8\E""``
M"?@@`R$@```0`+R/``!$C"R!F8\E""``"?@@`R4((``0`+R/(2A``C2!F8\A
M,&`""?@@`R$@0``L$+^/*!"SCR00LH\@$+&/'!"PCP@`X`,P$+TG0@`</.#_
MO2=@1)PG'`"_KQ``O*]4@)F/)0@@``GX(`,A(```$`"\CP``1(PL@9F/)0@@
M``GX(`,E""``$`"\C___!208@9F/)0@@``GX(`,A($``$`"\CR4((`!4@)F/
M)0@@``GX(`,A(```$`"\CP``1(PL@9F/)0@@``GX(`,E""``$`"\CT``!3PT
M@)F/'`"_CR$@0`"P+J4D(3````@`(`,@`+TG0@`</.#_O2=@1)PG'`"_KQ@`
ML*\0`+RO5("9CR4((``)^"`#(2```!``O(\``$2,+(&9CR4((``)^"`#)0@@
M`!``O(\E""``B(&9CR4((``)^"`#(2!``!``O(\``$*,5("9CP0`4(P)^"`#
M(2```!``O(\``$2,+(&9CR4((``)^"`#)0@@`!``O(\E""``6(&9CR4((``)
M^"`#(2!``!``O(\``$*05("9CQ@``J()^"`#(2```!``O(\``$2,+(&9CR4(
M(``)^"`#)0@@`!``O(\E""``B(&9CR4((``)^"`#(2!``!``O(\``$*,5("9
MCP0`4(P)^"`#(2```!``O(\``$2,+(&9CR4((``)^"`#)0@@`!``O(\E""``
M5(&9CR4((``)^"`#(2!`````0HP0`+R/$`!"C%2`F8__`4(P(2````GX(`,:
M``*F$`"\CP``1(PL@9F/)0@@``GX(`,E""``$`"\CR4((`"(@9F/)0@@``GX
M(`,A($``$`"\CP``0HQ4@)F/!`!0C`GX(`,A(```$`"\CP``1(PL@9F/)0@@
M``GX(`,E""``$`"\CT``!3QT@)F/H&6E)"$P```)^"`#(2!``!``O(\A(```
M5("9CR4((``)^"`#'``"KA``O(\``$2,+(&9CR4((``)^"`#)0@@`!``O(\E
M""``B(&9CR4((``)^"`#(2!``!``O(\``$*,5("9CP0`4(P)^"`#(2```!``
MO(\``$2,+(&9CR4((``)^"`#)0@@`!``O(\E""``8(&9CR4((``)^"`#(2!`
M`!``O(\``$*,5("9CR```JX)^"`#(2```!``O(\``$2,+(&9CR4((``)^"`#
M)0@@`!``O(\E""``B(&9CR4((``)^"`#(2!``!``O(\``$*,5("9CP0`4(P)
M^"`#(2```!``O(\``$2,+(&9CR4((``)^"`#)0@@`!``O(\E""``D("9CR4(
M(``)^"`#(2!`````0HP0`+R/%`!`$"4((`!4@)F/)0@@``GX(`,A(```$`"\
MCP``1(PL@9F/)0@@``GX(`,E""``$`"\CR4((`"0@)F/)0@@``GX(`,A($``
M``!"C!``O(]L`$*,5("9CR0``JX)^"`#(2```!``O(\``$2,+(&9CR4((``)
M^"`#)0@@`!``O(\E""``B(&9CR4((``)^"`#(2!`````0HP0`+R/!`!"C%2`
MF8\A(```"?@@`R@`0*P0`+R/``!$C"R!F8\E""``"?@@`R4((``0`+R/)0@@
M`(B!F8\E""``"?@@`R$@0````$*,$`"\CP0`0HQ4@)F/(2````GX(`,L`$"L
M$`"\CP``1(PL@9F/)0@@``GX(`,E""``$`"\CR4((`"(@9F/)0@@``GX(`,A
M($``$`"\CP``0HQ4@)F/!`!0C`GX(`,A(```$`"\CP``1(PL@9F/)0@@``GX
M(`,E""``$`"\CR4((`!D@)F/)0@@``GX(`,A($````!"C"4((``P``*N'`"_
MCQ@`L(\(`.`#(`"])T(`'#P8_[TG8$2<)^0`OZ_@`+ZOW`"WK]@`MJ_4`+6O
MT`"TK\P`LZ_(`+*OQ`"QK\``L*\0`+RO!0"`$"&0@````(*`)0@@``T`0!0E
M""``Y`"_C^``OH_<`+>/V`"VC]0`M8_0`+2/S`"SC\@`LH_$`+&/P`"PCP@`
MX`/H`+TG!(&9CR4((``)^"`#)0@@`!``O(_N_T`0(8A``$``$#Q``!,\0``7
M/$!D$"9$9',F2&3W)A@`MB?__Q4D`$`>).B`F8\E""``"?@@`R$@(`(0`+R/
M0P!`$"4((``3`$.0```$DB4((`!*`&00$P!')```8I(E""``30!B$"4((`#8
M@)F/(2!``@GX(`.X`*>O$`"\C[@`IX_8@)F/(2#@``GX(`,AH$``$`"\CR$0
M@@*D@)F/)0@@``GX(`,"`$0D$`"\C[@`IX^,@9F/(2!``"$HX`(A,$`""?@@
M`R&@0``0`+R/`P`$)%R!F8\A*(`""?@@`R$PP`(0`+R/!@!5$"4((``P`**/
M)0@@``#P0C`S`%X0)0@@`-2`F8\E""``"?@@`R$@@`(0`+R/)0@@`!R!F8\E
M""``"?@@`R$@@`(0`+R/)0@@`.B`F8\E""``"?@@`R$@(`(0`+R/O_]`%"4(
M(`"X@)F/)0@@``GX(`,A("`"$`"\CR4((`"8@)F/)0@@``GX(`,A($`"D/\`
M$"4((``!`.20`0`"DB4((`"G_X(0)0@@`+'_`!`E""```0#CD`$`8I(E""``
ML/]B%"4((``"`..0`@!BDB4((`";_V(0)0@@`*G_`!`E""``S0P0#"$@@`(0
M`+R/T/\`$"4((`!"`!P\X/^])V!$G"<<`+^O&`"PKQ``O*]4@)F/(8"```GX
M(`,A(```$`"\CP``1(PL@9F/)0@@``GX(`,E""``$`"\CR4((`",@)F/)0@@
M``GX(`,A($``$`"\CR$P0``4@9F/`P`$)`GX(`,A*``"$`"\CP8`0!`E""``
M'`"_CR$0```8`+"/"`#@`R``O2=4@)F/)0@@``GX(`,A(```$`"\CP``1(PL
M@9F/)0@@``GX(`,E""``$`"\CR4((`",@)F/)0@@``GX(`,A($``&`!#C`!`
M`B0`\&,P$`"\CQ<`8A`E""``5("9CR4((``)^"`#(2```!``O(\``$2,+(&9
MCR4((``)^"`#)0@@`!``O(\E""``C("9CR4((``)^"`#(2!``!@`0XP`H`(T
M`/!C,!``O(_0_V(4)0@@``R!F8\A(``""?@@`P(`!20<`+^/`0!"+!@`L(\(
M`.`#(`"])T(`'#S0W[TG8$2<)RP@OZ\H(+*O)""QKR`@L*\0`+ROA(&9CR4(
M(``)^"`#&`"P)Q``O(]```4\C(&9CT``!SQ09*4D(3!``%QDYR0)^"`#(2``
M`A``O(\)`$$$'!"R)R&````L(+^/(1```B@@LH\D(+&/(""PCP@`X`,P(+TG
MB("9CR$@``(A*$`""?@@`P`0!B00`+R/\?]`!"&(0`"D@)F/)0@@``GX(`,!
M`$0D$`"\C^O_0!`A@$``X("9CR$P(`(A*$`"(2!```GX(`,AB!$"X_\`$```
M(*+##1`()0@@`$(`'#S`_[TG8$2<)SP`OZ\X`+:O-`"UKS``M*\L`+.O*`"R
MKR0`L:\@`+"O$`"\KP``HH`]``,D(8"@`"0`0Q`AD(``V("9CR4((``)^"`#
M(2```B$@0`(8`*4GF@H0#"&80``0`+R/)`!`$"&(0`#8@)F/)0@@``GX(`,A
M($``*Q!3`!``O(^-`$`4)0@@`````H(!`!`F```BHOS_0!0!`#$F(1```#P`
MOX\X`+:/-`"UCS``M(\L`+./*`"RCR0`L8\@`+"/"`#@`T``O2?8@)F/`0"P
M)`GX(`,A(``"(2!``A@`I2>:"A`,(9A``!``O(_>_T`4(8A``,"`E(\E""``
M``"$CB4((````(*,)0@@`&X`0!`A$(``(8@```0`0B0``$.,)0@@`/S_8!0!
M`#$F`@`E)H`H!0!"``(\$,9#C"4((``+`&`0`0`#)&2!F8\E""``"?@@`R4(
M(``0`+R/(:A``!,`0!0``(*NS?\`$/__`B2D@)F/$,9#K`GX(`,A(*``$`"\
MC_C_0!`AJ$``A("9CX"P$0```(6.(2!```GX(`,A,,`"$`"\CP(``!```)6N
M@+`1``$`(B:`$`(`(:BB`@``H*X8`+&O``!"@B4((``.`$`0(1@``#T``R0]
M`$,0(1!``@,``!`]``0D!P!D$",84@`!`$(D``!#@"4((`#Z_V`4)0@@`",8
M4@"D@)F/``""C@(`9"8A((,`"?@@`R&P5@`0`+R/S_]`$```PJ[`@(*/)0@@
M````0XP8`**/)0@@`(`0`@`A$&(```!#C```0H(E""``#0!`$```8J`]``0D
M"P!$$#T``B0#```0`0!2)@<`1!`]``(D``!"@@$`8R0``&*@^O]`%`$`4B8]
M``(D``!BH`$`8R0```*"`0`0)@``8J#\_T`4`0!C)'O_`!`A$```&`"VC\"`
ME(_!_P`0@+`6``@`!229_P`0(8@``,W_`!`A&```0@`</*#_O2=@1)PG7`"_
MKU@`OJ]4`+>O4`"VKTP`M:](`+2O1`"SKT``LJ\\`+&O.`"PKQ@`O*]"``(\
M',14C$```CQX9$(D*`"BKT```CR`9$(D+`"BKT```CR(9$(D0``1/$``$#PP
M`**O0``"/&!D,29P9!`FH&5")$``%3PT`**O(9B``"``L:\D`+"OG&2U)@P`
M`!`H`+(G"?@@`R4((``8`+R/)@!`$"4((`````*")0@@`!8`0!`AB``"``!0
MC@0`4B;H"A`,(2`@`A@`O(\A*&`"J("9CR&X0``%`$`0(2!`````0H`E""``
MZO]`%"4((``A("`"_`T0#"$H8`(```*")0@@`.S_0!0AB``"7`"_CU@`OH]4
M`+>/4`"VCTP`M8](`+2/1`"SCT``LH\\`+&/.`"PCP@`X`-@`+TGV("9CR4(
M(``)^"`#(2!@`A@`O(\A((`"V("9CR4((``)^"`#(?!``!@`O(\A(.`"V("9
MCR4((``)^"`#(;!``!@`O(\AL-8#I("9CP$`Q"8)^"`#(2""`!@`O(\AL$``
MC(&9CR$@0``A**`"(3!@`B$X@`()^"`#$`"WKR$@(`+\#1`,(2C``KC_`!`E
M""``0@`</*C_O2=@1)PG5`"_KU``LZ],`+*O2`"QKT0`L*\0`+RO0``#/,!G
M8R08`*(G(`!D)```:(P$`&>,"`!FC`P`98P0`&,D``!(K`0`1ZP(`$:L#`!%
MK/;_9!00`$(D``!CE$``!#P``$.D#@L0#*1DA"1```0\#@L0#+!DA"1```0\
M#@L0#+ADA"1```0\Q&2$)`X+$`Q``!`\#@L0#,QD!"9```0\W&2$)`X+$`Q`
M`!(\Z&1$)@X+$`Q``!$\)&0D)@X+$`Q``!,\#@L0#/1D9"9```0\#@L0#`!E
MA"1```0\#@L0#`QEA"1```0\#@L0#!QEA"1```0\#@L0#"AEA"1```0\Z`H0
M##1EA"0#`$`0(2A``/P-$`ST9&0F0``$/.@*$`Q(980D!0!`$"4((`!```0\
M7&6$)/P-$`PA*$``0``$/.@*$`QH980D#P!`$$``!#SH9$0F_`T0#"$H0`!`
M``4\S&0$)OP-$`R89:4D5`"_CU``LX],`+*/2`"QCT0`L(\(`.`#6`"])^@*
M$`QX980D$`"\CP4`0!`D9"0F_`T0#"$H0`#N_P`00``%/&R`F8]```4\C&6E
M)"D`I"<)^"`#"@`&).7_0!0D9"0F_`T0##,`I2?B_P`00``%/$(`'#S@_[TG
M8$2<)QP`OZ\0`+ROQ("9CR4((``)^"`#)0@@`!``O(\E""``T("9CR4((``)
M^"`#(2!```(`0!`E""````!"C!P`OX\E""``"`#@`R``O2="`!P\V/^])V!$
MG"<D`+^O(`"QKQP`L*\0`+RO+@"`$"&(@````(*`)0@@`"H`0!`E""``V("9
MCR4((``)^"`#)0@@`/__1B0A,"8"*Q`F`A``O(\2`$`00@`%/!C$HHP``,2`
M``!#@"4((``)`(,0___&)`$`QB0M```0___&)```PH`E""``*`!$%"4((`#_
M_\8D*Q`F`OG_0!0E""``*`#1%"4((``8Q*2,``##@```@H`E""``.`!B$"4(
M(`!$@)F/)`"_CR``L8\<`+"/"``@`R@`O2>D@)F/)0@@``GX(`,"``0D!P!`
M$$```SQ`9&200&1C)```1*`!`&.0)0@@``$`0Z`D`+^/(`"QCQP`L(\(`.`#
M*`"])P``PH`E""``WO]#$"4((`#__\8D*Q`F`OG_0!0E""``VO_1$"4((``8
MQ*2,___&)"L0)@(&`$`0)0@@````PX```(*`)0@@`/C_8A`E""``(S#1``(`
MPB0!$$(LX_]`$$(`$#Q0@9F/(2@@`@$`QB0)^"`#%,8$)MS_`!`4Q@(FI("9
MCR4((``)^"`#`@`$)-;_0!!```,\0&1D)`$`A)!`9&.0`0!$H-#_`!```$.@
M0@`</-C_O2=@1)PG)`"_KR``L:\<`+"O$`"\K[D/$`PAB(````!#@"4((``D
M`&`00@`$/!C$A(PA@$````"$@`$`0B0<`&00)0@@````0X`E""``^_]@%`$`
M0B3P"A`,)0@@`!``O(\.`$`0)0@@``P`(!(E""`````B@B4((``(`$`00``%
M/*B`F8^<9:4D"?@@`R$@``(0`+R/"@`"$B4((``D`+^/(`"QCQP`L(\(`.`#
M*`"])^3_`!`A@$``YO\`$"&`0``A("`")`"_CR``L8\<`+"/S0P0""@`O2="
M`!P\T/^])V!$G"<L`+^O*`"RKR0`L:\@`+"O&`"\KUB`F8\P`*2O-`"EKS@`
MIJ\P`*0G-`"E)PGX(`,X`*8G&`"\CR4((`!P@86/G("9C_2`A(\)^"`#(3"@
M`!@`O(\E""``((&9CR4((``)^"`#(2``````0H`8`+R/(0!`%"4((``D@9F/
M)0@@``GX(`,E""``0@`#/!@`O(_(`$`0%-9BK.R`F8\E""``"?@@`R$@0``8
M`+R/)0@@`%2`F8\E""``"?@@`R$@```8`+R/``!$C"R!F8\E""``"?@@`R4(
M(``8`+R/)0@@`'R`F8\E""``"?@@`R$@0``8`+R/``!`H%2`F8\E""``"?@@
M`R$@```8`+R/``!$C"R!F8\E""``"?@@`R4((``8`+R/)0@@`%"`F8\E""``
M"?@@`R$@0``8`+R/``!#D%2`F8\"`&,T``!#H`GX(`,A(```&`"\CP``1(PL
M@9F/)0@@``GX(`,E""``&`"\CR4((`!0@)F/)0@@``GX(`,A($````!#D!@`
MO(\!`&,T``!#H#``I(\E""``!0"$)``0A$1T`(`$(1"`1@`0@$1```(\`!B`
M1"4((````")&^&="Q"4((`#\9T/$)0@@`#P0($8E""``>@`!124((`!X@)F/
M)0@@``GX(`.`(`0`-`"HCT(``SP@UF*L```$C00`!R1"``4\&`"\CS``IH\<
MUJ>L``!$K$``!#RD980D!`!$K!"!A(\"`,,H"`!$K$``!#RH980D"P!@%`P`
M1*PA($```0`#)(`H`P`A*`4!``"GC`$`8R0J*&8`$`"'K/G_H!0$`(0D`P#&
M)(`8!@!"`!`\=(&9CQ36!(XA&$,`0``%/```8*ST7*4D$`"@KPGX(`,A.$``
M&`"\CQT`0!`AB$``L("9CQ36!(X)^"`#)0@@`$``!#SH"A`,W&2$)!@`O(\C
M`$`00@`2/!36!(Y\@9F/)0@@``GX(`,E""``&`"\CR4((```@9F/)0@@``GX
M(`,E""``+`"_CR$0(`(H`+*/)`"QCR``L(\(`.`#,`"])T2!F8\4U@2."?@@
M`R4((``8`+R/%-8$CK"`F8\E""``"?@@`R&(0`!```0\Z`H0#-QDA"08`+R/
MW_]`%$(`$CP8UD2.)0@@``P`@!`E""``+!`0#"4((``8`+R/UO\`$"4((`!`
M``(\\&="Q"4((`#T9T/$B/\`$```(D9```0\Z`H0#.ADA"08`+R/(2!``,G_
M0!`8UD*N[?\`$"4((`!`@)F/)0@@``GX(`,!``0D0``$/&"`A8^`@)F/)0@@
M``GX(`.@9H0D0@`</+#OO2=@1)PG3!"_KT@0OJ]$$+>O0!"VKSP0M:\X$+2O
M-!"SKS`0LJ\L$+&O*!"PKQ@`O*\AD(``0``$/.ADA"3H"A`,(9B@`!@`O(]"
M``,\&,1PC*B`F8\A($`"(2@``@GX(`,AB$``&`"\CQ(`0!`E""``0``$/`QE
MA"3\#1`,(2A``DP0OX\A$$`"2!"^CT00MX]`$+://!"UCS@0M(\T$+./,!"R
MCRP0L8\H$+"/"`#@`U`0O2?8@)F/)0@@``GX(`,A($`"&`"\CT(``SP<Q'2,
ME("9CR$@8`(A*(`""?@@`R&H0``8`+R/X?]`$"$P0`!``!<\0``6/$!D]R8!
M`+4FG&36)B``LR<`@!XT``#"@"4((``"`$`4)0@@`"$PX`()`"`2(2C``$R`
MF8\@$*:O"?@@`R$@(`(8`+R/(!"FCTL`0!`E""``V("9CR$@P``)^"`#(!"F
MKR`0IH\```2"(1C"`/__98`8`+R/!P"D%"4((`#__V"@_O]D@```!8+__T(D
M^_^D$/__8R0A$*("`!!"*+;_0!`A*,`"C(&9CR$X``(A(&`""?@@`Q``LJ\8
M`+R/)0@@`%2`F8\E""``"?@@`R$@```8`+R/``!$C"R!F8\E""``"?@@`R4(
M(``8`+R/)0@@`(R`F8\E""``"?@@`R$@0``8`+R/(3!``%R!F8\#``0D"?@@
M`R$H8`(8`+R/%@!`%"4((`!4@)F/)0@@``GX(`,A(```&`"\CP``1(PL@9F/
M)0@@``GX(`,E""``&`"\CR4((`",@)F/)0@@``GX(`,A($``&`!"C!@`O(\`
M\$(P"@!>$"$@8`*4@)F/(2````GX(`,A*(`"&`"\CZ'_0!0A,$``>?\`$$``
M!#P,@9F/)0@@``GX(`,!``4D&`"\C_'_0!1```0\#&6$)/P-$`PA*&`"&`"\
MCR4((`!$@)F/)0@@``GX(`,A(&`":O\`$"&00``0@+TG0@`</.Q_OZ_H?[ZO
MY'^WK^!_MJ_<?[6OV'^TK]1_LZ_0?[*OS'^QK\A_L*]@1)PG"/Z])R``O*]`
M``(\M&5")#@`HJ]```(\0&1")#P`HJ]```(\8&5")%P`HJ]```(\O&5")&``
MHJ]```(\[&1")&0`HJ]```(\Q&5")&@`HJ]``!0\0``1/$``$#Q``!,\0``2
M/$```CR@93$FT&5")*QE$"9<97,FR&52)B&P@`#H9(0F+`"BKS0`L*]``+&O
M6`"SKVP`L:\H`+*OZ`H0##``L:\%`$`0)0@@````0X`E""``3@%@%*R!`S2C
M#Q`,)0@@`"``O(]7`4`0(:A`````LH(E""``%@!`$B$@8`+\@)F/)0@@``GX
M(`,E""``(1B@`E\`!20``$2,0)`2`"&0D@```$26)0@@``@`A#`"`(`4)0@@
M````9:`!`&,D``!R@"4((`#S_T`6)0@@`"$@8`('```07`"S)P``9(XE""``
M``""@"4((``2`4`0!`!S)N@*$`PE""``(9!``/;_0!`A($``:@T0#"4((``@
M`+R/\?]`$"4((`!$@)F/)0@@``GX(`,A($`"(`"\C^K_0!`A,$``L($(-"%`
M'0'8@)F/```&K0GX(`,A(,``(`"\CR$@H`+8@)F/)0@@``GX(`,A@$``(`"\
MCR&``@*D@)F/!`00)@GX(`,A(``"(`"\CR$@``*D@)F/)0@@``GX(`,A@$``
M(9!``$```CQ"``,\(`"\CYQE0B2P@0DT&,1SC"%(/0$0`**O%`"UKXR!F8\`
M`":-0``%/-QEI20A($`""?@@`R$X8`(@`+R/(2!``H"!F8\E""``"?@@`\`!
M!23__P,D(`"\CZ0`0Q`E""``%(&9CP,`!"0A*$`""?@@`P`!IB?__P,D(`"\
MCUT"0Q``0`(D&`&CCR4((```\&,PJ0!B%"4((`#$@)F/(`&UCPGX(`,E""``
M(`"\CZ(`HA;``0(D&`&CCR4((`#_`6,PG0!B%$``!#SH"A`,@&2$)"``O(_J
M`$`0)0@@`$2`F8\``-6."?@@`R$@0``A(*`"7A$0#"$H0``@`+R/X`!`$"&H
M0`#8@)F/)0@@``GX(`,A(*`"(;A```0`0B@@`+R/(P!`%/S_Y"9,@)F/0``%
M/"$@I`()^"`#A&:E)"``O(\;`$`4!``")`8`XA(AN+<"^__C@@``8H(E""``
M%`!B%"4((``$`-:.)0@@`!``P!(E""``V("9CR4((``)^"`#(2#``@0`0RP@
M`+R/"`!@%/S_0B1,@)F/0``%/"$@P@()^"`#C&:E)`(`0!`E""``(;"@`O`*
M$`PAJ``"(`"\CPD`0!1```0\:("9CR$@P`()^"`#(2@``"``O(^K`$`4(;A`
M`$``!#Q```4\)&2$)/P-$`R89:4D(`"\CR&P``"$@9F/)0@@``GX(`/__Q<D
M(`"\CT``!3R,@9F/$`"BKQ0`L:^L9J4D(2```B$P0`()^"`#(3A@`B``O(\7
M```0$0`>)`GX(`,E""``(`"\CP``0HR$@9F/&0!>%"4((``)^"`#)0@@`"``
MO(]```4\C(&9CQ``HJ\4`+:O&`"QKR$@``*\9J4D(3!``@GX(`,A.&`"(`"\
MCR4((`"`@9F/(2```@GX(`/``04D(`"\CR4((`"0@9F/XO]7$`$`UB8<@9F/
M)0@@``GX(`,A($`"Z&2$)OP-$`PA*``"M0X0#"$@``(>```0^`&])Y"!F8\E
M""``"?@@`R4((````$*,$0`#)"``O(]5_T,00``%/.2`@X\``,:.``!DC*R`
MF8\0`**OZ&6E)`GX(`,A.$`""@``$"&H``#D@(*/K("9CP``QHX``$2,0``%
M/%QFI20A.$`""?@@`R&H``#X`;TG['^_CR$0H`+H?[Z/Y'^WC^!_MH_<?[6/
MV'^TC]1_LX_0?[*/S'^QC\A_L(\(`.`#\'^])P<``!`X`+(G``!0CB4((```
M``*")0@@`/G^0!`$`%(F:@T0#"$@``(@`+R/]O]`$"$P``!$@)F/)0@@``GX
M(`,A(``"(`"\C^__0!`A,$``[/X`$+"!"#0A&'T`(2!``+4.$`P``&*LK($$
M-"``O(\A()T```""C$2`F8\E""``"?@@`R$@0`#/_P`0(:A``"$@0`(L`+(G
MZ`H0#"4((``@`+R/)0@@`$2`F8\&`$`0(2!```GX(`,E""``(`"\CYW^0!0A
MJ$````!$CB4((````(*`)0@@`.__0!0$`%(F0``5/*S^`!#09K4F``#5CA__
M`!`E""``2(&9CP(`'B3N_P8D__\')"$@0``)^"`#$`"^KR``O(^@`;8G*(&9
MCR$@X`(A*,`""?@@`P8`!B2@`:*3(`"\CP4`0!1#``,DH0&BDR4((`!6`4,0
M00`#)$B!F8\A(.`"$`"@KR$P```)^"`#(3@``$5G`CP!(T(TG`"BK\WO`CR)
MJT(TH`"BK[J8`CS^W$(TI`"BKS(0`CQV5$(TJ`"BK]+#`CSPX4(TK`"BKZ"!
M!#2D@0(TG`"C)R$070"X`*@G(2"=`"``O(^P`*"OM`"@K_@`H*\``$.L``"(
MK"B!F8\A(.`"(2C``@GX(`,`@`8T(`"\CWL`0!@A\$``L`"CC\`0'@`A$$,`
M*QA#`'(`8!0E""``M`"CCT(O'@#X`*2/(1AE`+``HJ]$`(`4M`"CKR$HP`)`
M`,(K-P!`%"$PP`,A$*``H($$-"$@G0```(.,0`!*)`,`28@'`$B("P!'B`\`
M1(@``$F8!`!(F`@`1Y@,`$28$`!")```::P$`&BL"`!GK`P`9*SR_TH4$`!C
M)*2!"#0A0!T!```$C:R!"32H@0,TL($(-,#_QB0A2#T!(1A]`"%`'0$``"*M
M``!EK/@%$`P```:ML($)-"%(/0$``":-K($$-*B!"#0A()T`(4`=`4``PR@@
M`+R/``""C```!8W4_V`0H($$-,#_WB>"$1X``0!#)(`9`P"`$0(`(2BC`"/P
MP@.@@0DT(4@]`>"`F8\``"2-"?@@`R$PP`,@`+R/J?\`$/@`OJ]```DD(Q`D
M`2HH7@`"`*`0(1C``R$80`"@@0(T(1!=````0HRH@0@TX("9CR%`'0$A($0`
M(3!@`````ZT)^"`#(2C``JB!"30A2#T!^`"BCP``(XU```0D(1!B`"``O(^/
M_T04^`"BKZ2!"#0A0!T!(2C#`@``!(T``"6M^`40#"/PPP.H@0DT(4@]`2``
MO(\``"6-F?\`$$``PBNT`*./CO\`$`$`8R2T@)F/)0@@``GX(`,A(.`"L`"V
MCX#_!23"$!8`/P!",`$`1"0Y`(,H(1"B`R``O(^T`+>/<P!@$+@`1:"@@0(T
M(1!=````0HPX@9F/.``&)",PQ``A*```"?@@`R$@1`"D@0,T(1A]````9(P"
M1A<``CP7``(R%P`"+A8``AP6``(2%@#P`*BC\0"GH_(`IJ/S`+>C]`"EH_4`
MHZ/V`**C^`40#/<`MJ.L`**/I($(-*0`I(^H`*./`DP"`"%`'0$@`+R/```)
MK;B!"#0"Q@0``GP$``)R!``";@,``F0#``):`P`"2@(`(4`=`4\`I*-3`*.C
MN($$-*2!`S2<`*>/H`"ECP``":TA&'T`(2"=`*"!"#0``&.0``"$D`+R!P`"
MO@4``K0%`'``J2<"-@<``OP'``+*!0`"5@(`(4`=`48`OJ-(`+>C20"VHP``
M":U%`+^C1P"GHTH`N:-+`*6C3`"XHTT`KZ-.`*ZC4`"MHU$`K*-2`*NC5`"J
MHU4`HZ-6`*2C5P"BHT0`IJ,AL"`!10"W)P,``!"8`+XG``#FD@$`]R:,@9F/
M0``%/"$@P`*D9J4D"?@@`P(`UB8@`+R/]O_>%J"!"#0A0!T!```(C8R!F8\0
M`*BO%`"QKY@`H*-```4\E&:E)"$X8`(A(``""?@@`R$P0`(@`+R/5/X`$"4(
M(`"@@0(T(1!=````0HPX@9F/0``&)",PQ``A*```"?@@`R$@1`"D@0,T(1A]
M````9(SX!1`,)0@@`*"!!#0A()T```"$C+@`H*\T`("L!`"`K`@`@*P,`("L
M$`"`K!0`@*P8`("L'`"`K"``@*PD`("L*`"`K"P`@*QX_P`0,`"`K)"!F8\E
M""``"?@@`R&H```@`+R/``!"C.2`@X\``,:.``!DC*R`F8]```4\$`"BKR1F
MI20)^"`#(3A``DO^`!#X`;TGH@&DDR4((`"H_H,4)0@@`*,!HY,E""``I/YB
M%$@``B2D`:.3)0@@`*#^8A1%``(DI0&CDR4((`"<_F(4(2#@`DB!F8_&_P8D
M__\')`GX(`,0`+ZO(`"\CR$@X`(H@9F/(2C``@GX(`,I``8D(`"\CQ``MJ^,
M@9F/I_\`$!0`L:]"`!P\P/^])V!$G"<\`+^O.`"VKS0`M:\P`+2O+`"SKR@`
MLJ\D`+&O(`"PKQ``O*]4@)F/)0@@``GX(`,A(```$`"\CP``1(PL@9F/)0@@
M``GX(`,E""``$`"\CR4((``(@9F/)0@@``GX(`,A($```0`#)$``!#P``$.@
MZ`H0#,QDA"00`+R/!0!`$#$``R0``$2`)0@@`#8!@Q`E""``*@\0#"4((``0
M`+R/)0@@`%2`F8\E""``"?@@`R$@```0`+R/``!$C"R!F8\E""``"?@@`R4(
M(``0`+R/0``%/#R!F8\A($``V&:E)`$`!B0)^"`#"P`')!``O(]4`$`0)0@@
M`$(`$SP<UF..#`!$C`(`8B@8`)2,,`%`%"4((``AB````0`0)`T``!!"`!4\
M3("9CPP`18P)^"`#(2!``A``O(\]`$`4)0@@`!S68XX!`!`F*A`#`CH`0!`!
M`#$F5("9CR4((``)^"`#(2```!``O(\``$2,+(&9CR4((``)^"`#)0@@`!``
MO(\A($``O("9CR$H@`(A,"`""?@@`R$X```0`+R/)`!`$"&P0````$*,(-:E
MC@@`0XR`(!``(2"D```$8S```)*,V/]@%"4((`!4@)F/)0@@``GX(`,A(```
M$`"\CP``1(PL@9F/)0@@``GX(`,E""``$`"\CP``Q8XP@)F/(2!``"$P```)
M^"`#`@`')!``O(\A*$``3("9CR4((``)^"`#(2!``A``O(_%_T`0)0@@`!S6
M8XXE""``__]B))T`41`"`&,H5("9CR4((``)^"`#(2```!``O(\``$2,+(&9
MCR4((``)^"`#)0@@`!``O(]```4\/(&9CR$@0`#@9J4D`0`&)`GX(`,%``<D
M$`"\CQP`0!`A@$``5("9CR4((``)^"`#(2```!``O(\``$2,+(&9CR4((``)
M^"`#)0@@`!``O(\,``..-(&9CP``98Q```8\(2!```GX(`/D9L8D#``"CA``
MO(\``$*,)0@@``@`0XQ```(\)!!B`(<`0!0E""``5("9CR4((``)^"`#(2``
M`!``O(\``$2,+(&9CR4((``)^"`#)0@@`!``O(]```4\/(&9CR$@0`#L9J4D
M`0`&)`GX(`,%``<D$`"\CQH`0!`A@$``0``$/.@*$`P,980D$`"\CX4`0!`E
M""``5("9CR$@```)^"`#&`"BKQ``O(\``$2,+(&9CR4((``)^"`#)0@@`!``
MO(\,``..-(&9CP``98P8`*:/"?@@`R$@0``0`+R/)0@@`%2`F8\E""``"?@@
M`R$@```0`+R/``!$C"R!F8\E""``"?@@`T(`$CP0`+R/)0@@``B!F8\E""``
M"?@@`R$@0``0`+R/(2```%2`F8\E""``"?@@`P``0*`0`+R/``!$C"R!F8\E
M""``"?@@`R4((``0`+R/)0@@`$B`F8\E""``"?@@`R$@0`!```0\``!`K.@*
M$`SH9(0D$`"\CU\`0!`8UD*N@(&9CR$@0``)^"`#[0$%)!``O(\%`$`0$0`#
M)`,`0Q#__P,D>0!#%$(``SP\`+^/.`"VCS0`M8\P`+2/+`"SCR@`LH\D`+&/
M(`"PCP@`X`-``+TG8_]@%"4((``!`!`D5("9CR4((``)^"`#(2```!``O(\`
M`$2,+(&9CR4((``)^"`#`0`0)A``O(\A($``0(&9CR4((``)^"`#(2B``AS6
M8HX0`+R/*A`"`NS_0!0E""``2_\`$"4((`!4@)F/)0@@``GX(`,A(```$`"\
MCP``1(PL@9F/)0@@``GX(`,E""``$`"\CPP``XZ@@)F/``!EC`GX(`,A($``
M$`"\CVC_`!`E""```0!"@"4((`#,_D`0)0@@`,;^`!`E""``5("9CR4((``)
M^"`#(2```!``O(\``$2,+(&9CR4((``)^"`#)0@@`$(``SP@UF2,#``#C@``
MAHP``&6,+@L0#"$@0``0`+R/?/\`$"4((``9_P`0(8@``$(`$3P@UB2.%Q(0
M#"4((``8UD*N#``"CA``O(\``$*,)0@@``@`0XPE""````1C,#4`8!`E""``
M#`!"C-R`F8\@UB6."?@@`R$@0``,``..(-8DC@``8XPAB$``"`!BC!``O(\`
M!$(P``"2C!$`0!`E""``#`!BC$``!#R`@)F/\&:$)"$H0`(A,$``"?@@`R$X
M(`(@UF.,0``$/!C61HX``&6,@("9CR!GA"0)^"`#(3A``%2`F8\E""``"?@@
M`R$@```0`+R/``!$C"R!F8\E""``"?@@`R4((``0`+R/#``#CC"`F8\``&6,
M(2!``"$P```)^"`#`@`')!``O(_>_P`00``$/%2`F8\E""``"?@@`R$@```0
M`+R/``!$C"R!F8\E""``"?@@`R4((``0`+R/#``#CC"`F8\``&6,(2!``"$P
M```)^"`#`@`')!``O(^Y_P`0)0@@`$(`'#S@_[TG8$2<)QP`OZ\0`+RO5("9
MCR4((``)^"`#(2```!``O(\``$2,+(&9CR4((``)^"`#)0@@`!``O(]```4\
M0``'//B`AH]<@)F/'`"_CR$@0`!P9Z4DC&?G)`@`(`,@`+TG0@`</-C_O2=@
M1)PG)`"_KQ@`O*]4@)F/)0@@``GX(`,A(```&`"\CP``1(PL@9F/)0@@``GX
M(`,E""``(Q<0#"$@0``8`+R/)0@@`%2`F8\E""``"?@@`R$@```8`+R/``!$
MC"R!F8\E""``"?@@`R4((``8`+R/0``'/*!EYR3P@)F/0``%/$``!CP0`*>O
M%`"@KR$@0`"89Z4D"?@@`TQ5QB0D`+^/)0@@``@`X`,H`+TG)0@@`"4((``"
M`!P\L.:<)R'@F0,<@(*/)0@@``8`0!`E""````!'C$R!F8\E""``"``@`R4(
M(`#[_P`0(3@``"4((``E""``"`#@`R4((``"`!P\:.:<)R'@F0/(_[TG-`"_
MKS``M:\L`+2O*`"SKR0`LJ\@`+&O'`"PKQ``O*\X@)F/(9B``"&@H``)^"`#
M(:C``!``O(\E""``(("1CR"`DH\E""``(Y!1`H.0$@`*`$`2(8``````.8X!
M`!`F(2!@`B$H@`()^"`#(3"@`BL0$@+X_T`4!``Q)C0`OX\P`+6/+`"TCR@`
MLX\D`+*/(`"QCQP`L(\(`.`#.`"])R4((``E""``0@`"/`3$68S8_[TG__\"
M)"0`OZ\@`+&O"@`B$QP`L*]"`!`\!,00)O__$20)^"`#_/\0)@``&8XE""``
M^_\Q%R4((``D`+^/(`"QCQP`L(\(`.`#*`"])R4((``E""``$("9CR%XX`,)
M^"`#>P`8)!"`F8\A>.`#"?@@`WH`&"00@)F/(7C@`PGX(`-Y`!@D$("9CR%X
MX`,)^"`#>``8)!"`F8\A>.`#"?@@`W<`&"00@)F/(7C@`PGX(`-V`!@D$("9
MCR%XX`,)^"`#=``8)!"`F8\A>.`#"?@@`W``&"00@)F/(7C@`PGX(`-O`!@D
M$("9CR%XX`,)^"`#;@`8)!"`F8\A>.`#"?@@`VT`&"00@)F/(7C@`PGX(`-L
M`!@D$("9CR%XX`,)^"`#:P`8)!"`F8\A>.`#"?@@`VH`&"00@)F/(7C@`PGX
M(`-I`!@D$("9CR%XX`,)^"`#:``8)!"`F8\A>.`#"?@@`V<`&"00@)F/(7C@
M`PGX(`-F`!@D$("9CR%XX`,)^"`#90`8)!"`F8\A>.`#"?@@`V0`&"00@)F/
M(7C@`PGX(`-C`!@D$("9CR%XX`,)^"`#8@`8)!"`F8\A>.`#"?@@`V$`&"00
M@)F/(7C@`PGX(`-@`!@D$("9CR%XX`,)^"`#7P`8)!"`F8\A>.`#"?@@`UX`
M&"00@)F/(7C@`PGX(`-=`!@D$("9CR%XX`,)^"`#7``8)!"`F8\A>.`#"?@@
M`UH`&"00@)F/(7C@`PGX(`-9`!@D$("9CR%XX`,)^"`#6``8)!"`F8\A>.`#
M"?@@`U<`&"00@)F/(7C@`PGX(`-6`!@D$("9CR%XX`,)^"`#4P`8)!"`F8\A
M>.`#"?@@`U(`&"00@)F/(7C@`PGX(`-1`!@D$("9CR%XX`,)^"`#3P`8)!"`
MF8\A>.`#"?@@`TX`&"00@)F/(7C@`PGX(`--`!@D$("9CR%XX`,)^"`#3``8
M)!"`F8\A>.`#"?@@`TL`&"00@)F/(7C@`PGX(`-*`!@D$("9CR%XX`,)^"`#
M2``8)!"`F8\A>.`#"?@@`T8`&"00@)F/(7C@`PGX(`-%`!@D$("9CR%XX`,)
M^"`#1``8)!"`F8\A>.`#"?@@`T,`&"00@)F/(7C@`PGX(`-"`!@D$("9CR%X
MX`,)^"`#00`8)!"`F8\A>.`#"?@@`T``&"00@)F/(7C@`PGX(`,_`!@D$("9
MCR%XX`,)^"`#/0`8)!"`F8\A>.`#"?@@`SP`&"00@)F/(7C@`PGX(`,[`!@D
M$("9CR%XX`,)^"`#.@`8)!"`F8\A>.`#"?@@`SD`&"00@)F/(7C@`PGX(`,X
M`!@D$("9CR%XX`,)^"`#-P`8)!"`F8\A>.`#"?@@`S8`&"00@)F/(7C@`PGX
M(`,U`!@D$("9CR%XX`,)^"`#-``8)!"`F8\A>.`#"?@@`S,`&"00@)F/(7C@
M`PGX(`,R`!@D$("9CR%XX`,)^"`#,0`8)!"`F8\A>.`#"?@@`S``&"00@)F/
M(7C@`PGX(`,N`!@D$("9CR%XX`,)^"`#+0`8)!"`F8\A>.`#"?@@`RP`&"00
M@)F/(7C@`PGX(`,K`!@D$("9CR%XX`,)^"`#*@`8)!"`F8\A>.`#"?@@`RD`
M&"00@)F/(7C@`PGX(`,H`!@D$("9CR%XX`,)^"`#)P`8)!"`F8\A>.`#"?@@
M`R0`&"00@)F/(7C@`PGX(`,C`!@D``````````````````````(`'#R0X)PG
M(>"9`^#_O2<<`+^O$`"\KP$`$00E""``0@`</&!$G"<8@)F/)0@@`+`6.2>J
M[!$$)0@@`!P`OX\E""``"`#@`R``O2<``````0`"`%!!4E]#3$5!3@```"]P
M<F]C+W-E;&8O97AE```N````+BX``"5S+R5S````+W!R;V,O)6DO)7,`97AE
M`$Q$7TQ)0E)!4EE?4$%42`!,24)0051(`$Q)0E)!4EE?4$%42`````!$64Q$
M7TQ)0E)!4EE?4$%42````"5S)7,E<P``4$523#5,24(`````4$523$Q)0@!0
M15),-4]05`````!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1`!005)?5$5-4`````!005)?1$5"54<```!005)?0T%#2$4```!005)?4%)/
M1TY!344`````4$%27T%21T,`````4$%27T%21U9?,```4$%27T=,3T)!3%]$
M14)51P````!005)?1TQ/0D%,7U1-4$1)4@```%!!4E]435!$25(``%!!4E]'
M3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`````%!!4E]#3$5!3CT``#$`
M``!P87(M`````"UE```M+0``0SI<5$5-4``O=&UP`````%1%35!$25(`5$U0
M`%5315(`````55-%4DY!344`````)7,E<R5S)7,`````)7,Z(&-R96%T:6]N
M(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI
M"@``)7,Z('-T870@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D
M("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@
M=6YS869E"@``<&%R;``````N<&%R`````"5S)7-C86-H92TE<R5S```E,#)X
M`````"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S`````%-94U1%
M30``05)'5@`````8````<&5R;``````P````)7,Z(&5X96-U=&EO;B!O9B`E
M<R!F86EL960@+2!A8F]R=&EN9R!W:71H("5I+@H`)7,Z(&-R96%T:6]N(&]F
M('!R:79A=&4@=&5M<&]R87)Y('-U8F1I<F5C=&]R>2`E<R!F86EL960@+2!A
M8F]R=&EN9R!W:71H("5I+@H```!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D
M97(`<&5R;'AS:2YC````26YT97)N86QS.CI005(Z.D)/3U0`````+P```#H`
M`````````````%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@````
M`````````````````````````/!!``"`____ST%P87(N<&P`````````````
M(R$O=7-R+V)I;B]P97)L"F5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@
M)#`@)'LQ*R(D0")])PH@("`@:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S
M;VUE('-H96QL"@IP86-K86=E(%]?<&%R7W!L.PH*(R`M+2T@5&AI<R!S8W)I
M<'0@;75S="!N;W0@=7-E(&%N>2!M;V1U;&5S(&%T(&-O;7!I;&4@=&EM92`M
M+2T*(R!U<V4@<W1R:6-T.PH*(VQI;F4@,34X"@IM>2`H)'!A<E]T96UP+"`D
M<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.
M?2D@>PH@("`@<F5Q=6ER92!&:6QE.CI496UP.PH@("`@<F5Q=6ER92!&:6QE
M.CI"87-E;F%M93L*("`@(')E<75I<F4@1FEL93HZ4W!E8SL*("`@(&UY("1T
M;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PH@
M("`@;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PH@
M("`@1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER
M(#H@=6YL:6YK('TL("1P87)?=&5M<"D["B`@("!R;61I<B`D<&%R7W1E;7`[
M"B`@("`C($1O;B=T(')E;6]V92!T;W!D:7(@8F5C875S92!T:&ES(&-A=7-E
M<R!A(')A8V4@=VET:"!O=&AE<B!A<'!S"B`@("`C('1H870@87)E('1R>6EN
M9R!T;R!S=&%R="X*"B`@("!I9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G
M35-7:6XS,B<I('L*("`@("`@("`C(%-O;65T:&EN9R!W96YT('=R;VYG('5N
M;&EN:VEN9R!T:&4@=&5M<&]R87)Y(&1I<F5C=&]R>2X@(%1H:7,*("`@("`@
M("`C('1Y<&EC86QL>2!H87!P96YS(&]N('!L871F;W)M<R!T:&%T(&1I<V%L
M;&]W('5N;&EN:VEN9R!S:&%R960*("`@("`@("`C(&QI8G)A<FEE<R!A;F0@
M97AE8W5T86)L97,@=&AA="!A<F4@:6X@=7-E+B!5;FQI;FL@=VET:"!A(&)A
M8VMG<F]U;F0*("`@("`@("`C('-H96QL(&-O;6UA;F0@<V\@=&AE(&9I;&5S
M(&%R92!N;R!L;VYG97(@:6X@=7-E(&)Y('1H:7,@<')O8V5S<RX*("`@("`@
M("`C($1O;B=T(&1O(&%N>71H:6YG(&]N(%=I;F1O=W,@8F5C875S92!O=7(@
M<&%R96YT('!R;V-E<W,@=VEL;`H@("`@("`@(",@=&%K92!C87)E(&]F(&-L
M96%N:6YG('1H:6YG<R!U<"X*"B`@("`@("`@;7D@)'1M<"`](&YE=R!&:6QE
M.CI496UP*`H@("`@("`@("`@("!414U03$%412`]/B`G=&UP6%A86%@G+`H@
M("`@("`@("`@("!$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O
M<&1I<BDL"B`@("`@("`@("`@(%-51D9)6"`]/B`G+F-M9"<L"B`@("`@("`@
M("`@(%5.3$E.2R`]/B`P+`H@("`@("`@("D["@H@("`@("`@('!R:6YT("1T
M;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PH@
M("!R;2`M<F8@)R1P87)?=&5M<"<*("`@:68@6R!<(2`M9"`G)'!A<E]T96UP
M)R!=.R!T:&5N"B`@("`@("!B<F5A:PH@("!F:0H@("!S;&5E<"`Q"B`@('@]
M8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@
M(B<*(CL*("`@("`@("`@("`@8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*
M("`@("`@("!M>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU
M;&P@,CXF,2`F)SL*("`@("`@("!C;&]S92`D=&UP.PH@("`@("`@('-Y<W1E
M;2@D8VUD*3L*("`@("`@("!O=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P
M<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0H@("`@("`@("`@("`@+B`D
M=&UP+3YF:6QE;F%M92D["B`@("!]"GT@?0H*0D5'24X@>PH@("`@26YT97)N
M86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ
M0D]/5#L*"B`@("!E=F%L('L*"E]P87)?:6YI=%]E;G8H*3L*"FEF("AE>&ES
M=',@)$5.5GM005)?05)'5E\P?2!A;F0@)$5.5GM005)?05)'5E\P?2`I('L*
M("`@($!!4D=6(#T@;6%P("1%3E9[(E!!4E]!4D=67R1?(GTL("@Q("XN("1%
M3E9[4$%27T%21T-]("T@,2D["B`@("`D,"`]("1%3E9[4$%27T%21U9?,'T[
M"GT*96QS92!["B`@("!F;W(@*&ME>7,@)45.5BD@>PH@("`@("`@(&1E;&5T
M92`D14Y6>R1??2!I9B`O7E!!4E]!4D=67R\["B`@("!]"GT*"FUY("1Q=6EE
M="`]("$D14Y6>U!!4E]$14)51WT["@HC(&9I>"`D<')O9VYA;64@:68@:6YV
M;VME9"!F<F]M(%!!5$@*;7D@)4-O;F9I9R`]("@*("`@('!A=&A?<V5P("`@
M(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`H@("`@7V5X92`@
M("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N
M97AE)R`Z("<G*2P*("`@(%]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I
M;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["@I?<V5T7W!R;V=N86UE*"D["E]S
M971?<&%R7W1E;7`H*3L*"B,@36%G:6,@<W1R:6YG(&-H96-K:6YG(&%N9"!E
M>'1R86-T:6YG(&)U;F1L960@;6]D=6QE<R![>WL*;7D@*"1S=&%R=%]P;W,L
M("1D871A7W!O<RD["GL*("`@(&QO8V%L("1324=[7U]705).7U]](#T@<W5B
M('M].PH*("`@(",@0VAE8VL@9FEL92!T>7!E+"!G970@<W1A<G0@;V8@9&%T
M82!S96-T:6]N('M[>PH@("`@;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R
M(&QA<W0["B`@("!B:6YM;V1E*%]&2"D["@H@("`@;7D@)&)U9CL*("`@('-E
M96L@7T9(+"`M."P@,CL*("`@(')E860@7T9(+"`D8G5F+"`X.PH@("`@;&%S
M="!U;FQE<W,@)&)U9B!E<2`B7&Y005(N<&U<;B(["@H@("`@<V5E:R!?1D@L
M("TQ,BP@,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@<V5E:R!?1D@L
M("TQ,B`M('5N<&%C:R@B3B(L("1B=68I+"`R.PH@("`@<F5A9"!?1D@L("1B
M=68L(#0["@H@("`@)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["B`@("`C
M('U]?0H*("`@(",@17AT<F%C=&EN9R!E86-H(&9I;&4@:6YT;R!M96UO<GD@
M>WM["B`@("!M>2`E<F5Q=6ER95]L:7-T.PH@("`@=VAI;&4@*"1B=68@97$@
M(D9)3$4B*2!["B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("`@("`@
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PH*("`@("`@("!M
M>2`D9G5L;&YA;64@/2`D8G5F.PH@("`@("`@(&]U=',H<7$H56YP86-K:6YG
M(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*("`@("`@("!M>2`D8W)C(#T@*"`D
M9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F
M.PH@("`@("`@(&UY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH
M/SHN*B\I/R@N*BDH7"XN*BE\*3L*"B`@("`@("`@<F5A9"!?1D@L("1B=68L
M(#0["B`@("`@("`@<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I
M.PH*("`@("`@("!I9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH
M/SIP;7QP;'QI>'QA;"DD+VDI('L*("`@("`@("`@("`@;7D@*"1O=70L("1F
M:6QE;F%M92D@/2!?=&5M<&9I;&4H)&5X="P@)&-R8RD["B`@("`@("`@("`@
M(&EF("@D;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@
M("`@("`@("`@("`@("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@("`@("`@
M("`@8VQO<V4@)&]U=#L*("`@("`@("`@("`@("`@(&-H;6]D(#`W-34L("1F
M:6QE;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B`@("`@("`@
M("`@("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL
M;F%M93L*("`@("`@("!]"B`@("`@("`@96QS:68@*"`D9G5L;&YA;64@/7X@
M;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PH@
M("`@("`@("`@("`C('-H;W5L9"!B92!M;W9E9"!T;R!?=&5M<&9I;&4H*0H@
M("`@("`@("`@("!M>2`D9FEL96YA;64@/2`B)$5.5GM005)?5$5-4'TO)&)A
M<V5N86UE)&5X="(["B`@("`@("`@("`@(&]U=',H(E-(3$E".B`D9FEL96YA
M;65<;B(I.PH@("`@("`@("`@("!O<&5N(&UY("1O=70L("<^)RP@)&9I;&5N
M86UE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@
M("`@("`@("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@("`@("!C;&]S92`D
M;W5T.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)')E
M<75I<F5?;&ES='LD9G5L;&YA;65](#T*("`@("`@("`@("`@)%!!4CHZ2&5A
M=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["B`@("`@("`@("`@("`@
M("!B=68@/3X@)&)U9BP*("`@("`@("`@("`@("`@(&-R8R`]/B`D8W)C+`H@
M("`@("`@("`@("`@("`@;F%M92`]/B`D9G5L;&YA;64L"B`@("`@("`@("`@
M('T["B`@("`@("`@?0H@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@
M?0H@("`@(R!]?7T*"B`@("!L;V-A;"!`24Y#(#T@*'-U8B!["B`@("`@("`@
M;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PH*("`@("`@("!R971U<FX@:68@
M<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["@H@("`@("`@(&UY("1F:6QE;F%M
M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*("`@
M("`@("`@("`@;7D@)&ME>3L*("`@("`@("`@("`@9F]R96%C:"`H:V5Y<R`E
M<F5Q=6ER95]L:7-T*2!["B`@("`@("`@("`@("`@("!N97AT('5N;&5S<R`O
M7%$D;6]D=6QE7$4D+SL*("`@("`@("`@("`@("`@("1K97D@/2`D7SL@;&%S
M=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!D96QE=&4@)')E<75I<F5?
M;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PH@("`@("`@('T@;W(@<F5T
M=7)N.PH*("`@("`@("`D24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N
M86UE+R1M;V1U;&4B.PH*("`@("`@("!I9B`H)$5.5GM005)?0TQ%04Y](&%N
M9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PH@("`@("`@("`@("!M>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PH@("`@("`@
M("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@('!R:6YT("1F:"`D9FEL
M96YA;64M/GMB=69].PH@("`@("`@("`@("!S965K*"1F:"P@,"P@,"D["B`@
M("`@("`@("`@(')E='5R;B`D9F@["B`@("`@("`@?0H@("`@("`@(&5L<V4@
M>PH@("`@("`@("`@("!M>2`H)&]U="P@)&YA;64I(#T@7W1E;7!F:6QE*"<N
M<&TG+"`D9FEL96YA;64M/GMC<F-]*3L*("`@("`@("`@("`@:68@*"1O=70I
M('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@
M("`@("!P<FEN="`D;W5T("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@
M("`@("!C;&]S92`D;W5T.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&]P
M96X@;7D@)&9H+"`G/"<L("1N86UE(&]R(&1I92`D(3L*("`@("`@("`@("`@
M8FEN;6]D92@D9F@I.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@("`@
M('T*"B`@("`@("`@9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T
M(&9I;F0@)&UO9'5L92%<;B(["B`@("!]+"!`24Y#*3L*"B`@("`C($YO=R!L
M;V%D(&%L;"!B=6YD;&5D(&9I;&5S('M[>PH*("`@(",@:6YI=&EA;&EZ92!S
M:&%R960@;V)J96-T('!R;V-E<W-I;F<*("`@(')E<75I<F4@6%-,;V%D97([
M"B`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E($-A<G`Z.DAE
M879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@("!005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H@("`@(R!N;W<@;&5T)W,@=')Y
M(&=E='1I;F<@:&5L<&5R(&UO9'5L97,@9G)O;2!W:71H:6X*("`@(')E<75I
M<F4@24\Z.D9I;&4["@H@("`@(R!L;V%D(')E<W0@;V8@=&AE(&=R;W5P(&EN
M"B`@("!W:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER
M95]L:7-T*5LP72D@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`]
M(%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@=6YL97-S
M("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2![
M"B`@("`@("`@("`@(",@<F5Q=6ER92!M;V1U;&5S+"!D;R!O=&AE<B!E>&5C
M=71A8FQE(&9I;&5S"B`@("`@("`@("`@(&EF("@D9FEL96YA;64@/7X@+UPN
M<&UC/R0O:2D@>PH@("`@("`@("`@("`@("`@<F5Q=6ER92`D9FEL96YA;64[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@
M("`@("`C(%-K:7`@06-T:79E4W1A=&4G<R!S:71E8W5S=&]M:7IE+G!L(&9I
M;&4Z"B`@("`@("`@("`@("`@("!D;R`D9FEL96YA;64@=6YL97-S("1F:6QE
M;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("!D96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA
M;65].PH@("`@?0H*("`@(",@?7U]"@H@("`@;&%S="!U;FQE<W,@)&)U9B!E
M<2`B4$M<,#`S7#`P-"(["B`@("`D<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M
M(#0["GT*(R!]?7T*"B,@07)G=6UE;G0@<')O8V5S<VEN9R![>WL*;7D@0'!A
M<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M
M92D["@ID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H
M4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*"B1Q=6EE="`](#`@
M=6YL97-S("1%3E9[4$%27T1%0E5'?3L*(R!$;VXG="!S=V%L;&]W(&%R9W5M
M96YT<R!F;W(@8V]M<&EL960@97AE8W5T86)L97,@=VET:&]U="`M+7!A<BUO
M<'1I;VYS"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R
M+6]P=&EO;G,G("8F('-H:69T*2D@>PH@("`@;7D@)61I<W1?8VUD(#T@<7<H
M"B`@("`@("`@<"`@(&)L:6)?=&]?<&%R"B`@("`@("`@:2`@(&EN<W1A;&Q?
M<&%R"B`@("`@("`@=2`@('5N:6YS=&%L;%]P87(*("`@("`@("!S("`@<VEG
M;E]P87(*("`@("`@("!V("`@=F5R:69Y7W!A<@H@("`@*3L*"B`@("`C(&EF
M('1H92!A<'`@:7,@:6YV;VME9"!A<R`B87!P;F%M92`M+7!A<BUO<'1I;VYS
M("TM<F5U<V4@4%)/1U)!32!`4%)/1U]!4D=6(BP*("`@(",@=7-E('1H92!A
M<'`@=&\@<G5N('1H92!G:79E;B!P97)L(&-O9&4@:6YS=&5A9"!O9B!A;GET
M:&EN9R!F<F]M('1H90H@("`@(R!A<'`@:71S96QF("AB=70@<W1I;&P@<V5T
M('5P('1H92!N;W)M86P@87!P(&5N=FER;VYM96YT(&%N9"!`24Y#*0H@("`@
M:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*("`@("`@
M("!S:&EF="!`05)'5CL*("`@("`@("`D14Y6>U!!4E]!4%!?4D554T5](#T@
M<VAI9G0@0$%21U8["B`@("!]"B`@("!E;'-E('L@(R!N;W)M86P@<&%R;"!B
M96AA=FEO=7(*"B`@("`@("`@;7D@0&%D9%]T;U]I;F,["B`@("`@("`@=VAI
M;&4@*$!!4D=6*2!["B`@("`@("`@("`@("1!4D=66S!=(#U^("]>+2A;04E-
M3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["@H@("`@("`@("`@("!I9B`H
M)#$@97$@)TDG*2!["B`@("`@("`@("`@("`@("!P=7-H($!A9&1?=&]?:6YC
M+"`D,CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@
M)TTG*2!["B`@("`@("`@("`@("`@("!E=F%L(")U<V4@)#(B.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G02<I('L*("`@("`@
M("`@("`@("`@('5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)T\G*2!["B`@("`@("`@("`@
M("`@("`D;W5T(#T@)#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS
M:68@*"0Q(&5Q("=B)RD@>PH@("`@("`@("`@("`@("`@)&)U;F1L92`]("=S
M:71E)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@
M)T(G*2!["B`@("`@("`@("`@("`@("`D8G5N9&QE(#T@)V%L;"<["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=Q)RD@>PH@("`@
M("`@("`@("`@("`@)'%U:65T(#T@,3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!E;'-I9B`H)#$@97$@)TPG*2!["B`@("`@("`@("`@("`@("!O<&5N
M("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO
M9SH@)"$B.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E
M<2`G5"<I('L*("`@("`@("`@("`@("`@("1C86-H95]N86UE(#T@)#(["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@('-H:69T*$!!4D=6*3L*"B`@("`@
M("`@("`@(&EF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PH@("`@("`@
M("`@("`@("`@9&5L971E("1%3E9[)U!!4E]414U0)WT["B`@("`@("`@("`@
M("`@("!I;FET7VEN8R@I.PH@("`@("`@("`@("`@("`@<F5Q=6ER92!005(Z
M.D1I<W0["B`@("`@("`@("`@("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@I
M('5N;&5S<R!`05)'5CL*("`@("`@("`@("`@("`@("9[(E!!4CHZ1&ES=#HZ
M)&-M9")]*"1?*2!F;W(@0$%21U8["B`@("`@("`@("`@("`@("!E>&ET.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!U;G-H:69T($!)3D,L
M($!A9&1?=&]?:6YC.PH@("`@?0I]"@HC(%A86"`M+2!A9&0@+2UP87(M9&5B
M=6<@<W5P<&]R="$*"B,@?7U]"@HC($]U='!U="!M;V1E("@M3RD@:&%N9&QI
M;F<@>WM["FEF("@D;W5T*2!["B`@("!["B`@("`@("`@(VQO8V%L("1)3D-[
M)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@
M("`@("!R97%U:7)E($E/.CI&:6QE.PH@("`@("`@(')E<75I<F4@07)C:&EV
M93HZ6FEP.PH@("`@?0H*("`@(&UY("1P87(@/2!S:&EF="A`05)'5BD["B`@
M("!M>2`D>FEP.PH*"B`@("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@("`@
M;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D
M<&%R)SH@)"$B.PH@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("!B;&5S
M<R@D9F@L("=)3SHZ1FEL92<I.PH*("`@("`@("`D>FEP(#T@07)C:&EV93HZ
M6FEP+3YN97<["B`@("`@("`@*"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H
M)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0H@("`@("`@
M("`@("!O<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["B`@("!]"@H*
M("`@(&UY("5E;G8@/2!D;R!["B`@("`@("`@:68@*"1Z:7`@86YD(&UY("1M
M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*("`@("`@("`@
M("`@)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B`@("`@("`@("`@("1M971A
M(#U^(',O7EQ3+BHO+VUS.PH@("`@("`@("`@("`D;65T82`]?B`O7B`@*%M>
M.ETK*3H@*"XK*20O;6<["B`@("`@("`@?0H@("`@?3L*"B`@("`C($]P96X@
M:6YP=70@86YD(&]U='!U="!F:6QE<R![>WL*("`@(&QO8V%L("0O(#T@7#0[
M"@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@("`@(&]P96X@4$%2+"`G
M/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["B`@("`@("`@8FEN;6]D92A0
M05(I.PH@("`@("`@(&1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL
M97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*("`@('T*"B`@("!#<F5A=&50
M871H*"1O=70I(#L*("`@(`H@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*
M("`@("`@("`D;W5T+`H@("`@("`@($E/.CI&:6QE.CI/7T-214%4*"D@?"!)
M3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"B`@
M("`@("`@,#<W-RP*("`@("D@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I
M.PH*("`@("0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@
M.B!U;F1E9CL*("`@('-E96L@7T9(+"`P+"`P.PH@("`@;7D@)&QO861E<B`]
M('-C86QA<B`\7T9(/CL*("`@(&EF("@A)$5.5GM005)?5D520D%424U](&%N
M9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PH@("`@("`@(')E<75I
M<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@("`@(%!!4CHZ1FEL=&5R
M.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"B`@("!]"B`@
M("!F;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["B`@("`@("`@
M;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*("`@("`@("`D=F%L(#T@
M979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*("`@("`@("!M>2`D;6%G
M:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["B`@("`@("`@
M;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*("`@("`@
M("`D;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B`@("`@("`@("`@("1M86=I
M8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI
M*0H@("`@("`@('UE9SL*("`@('T*("`@("1F:"T^<')I;G0H)&QO861E<BD[
M"B`@("`D+R`]('5N9&5F.PH@("`@(R!]?7T*"B`@("`C(%=R:71E(&)U;F1L
M960@;6]D=6QE<R![>WL*("`@(&EF("@D8G5N9&QE*2!["B`@("`@("`@<F5Q
M=6ER92!005(Z.DAE879Y.PH@("`@("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*("`@("`@("!I;FET7VEN8R@I.PH*("`@("`@("!R97%U
M:7)E7VUO9'5L97,H*3L*"B`@("`@("`@;7D@0&EN8R`]('-O<G0@>PH@("`@
M("`@("`@("!L96YG=&@H)&(I(#P]/B!L96YG=&@H)&$I"B`@("`@("`@?2!G
M<F5P('L*("`@("`@("`@("`@(2]"4T1004XO"B`@("`@("`@?2!G<F5P('L*
M("`@("`@("`@("`@*"1B=6YD;&4@;F4@)W-I=&4G*2!O<@H@("`@("`@("`@
M("`H)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`H@("`@
M("`@("`@("`@)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*
M("`@("`@("!]($!)3D,["@H@("`@("`@(",@1FEL92!E>&ES=',@=&5S="!A
M9&1E9"!T;R!F:7@@4E0@(S0Q-SDP.@H@("`@("`@(",@1G5N;GDL(&YO;BUE
M>&ES=&EN9R!E;G1R>2!I;B!?/"XN+BYA=71O+T-O;7!R97-S+U)A=R]:;&EB
M+V%U=&]S<&QI="YI>"X*("`@("`@("`C(%1H:7,@:7,@82!B86YD+6%I9"!F
M:7@@=VET:"!N;R!D965P97(@9W)A<W`@;V8@=&AE(&ES<W5E+@H@("`@("`@
M(",@4V]M96)O9'D@<&QE87-E(&=O('1H<F]U9V@@=&AE('!A:6X@;V8@=6YD
M97)S=&%N9&EN9R!W:&%T)W,@:&%P<&5N:6YG+`H@("`@("`@(",@22!F86EL
M960N("TM(%-T969F96X*("`@("`@("!M>2`E9FEL97,["B`@("`@("`@+UY?
M/"@N*RDD+R!A;F0@+64@)#$@86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y<R`E
M.CH["B`@("`@("`@)&9I;&5S>R1??2LK(&9O<B!V86QU97,@)4E.0SL*"B`@
M("`@("`@;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[
M"B`@("`@("`@;7D@)7=R:71T96X["@H@("`@("`@(&9O<F5A8V@@*'-O<G0@
M:V5Y<R`E9FEL97,I('L*("`@("`@("`@("`@;7D@*"1N86UE+"`D9FEL92D[
M"@H@("`@("`@("`@("!F;W)E86-H(&UY("1D:7(@*$!I;F,I('L*("`@("`@
M("`@("`@("`@(&EF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[
M)%]]*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&4@/2`D7SL*("`@("`@
M("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@
M>PH@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"0Q+"`D
M,BD["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@(&5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N
M*EM>0V-=*5Q:(2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AM>2`D<F5F
M(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["B`@
M("`@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@(&5L<VEF("@M9B`B)&1I<B\D,2(I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H
M(B1D:7(O)#$B+"`D,2D["B`@("`@("`@("`@("`@("`@("`@("`@(&QA<W0[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"@H@("`@("`@("`@("!N97AT('5N;&5S<R!D969I;F5D("1N
M86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["B`@("`@("`@("`@(&YE
M>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<
M120O.PH@("`@("`@("`@("!O=71S*"!J;VEN("(B+`H@("`@("`@("`@("`@
M("`@<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z
M("1F:6QE+`H@("`@("`@("`@("`@("`@<7$H(BXN+BD*("`@("`@("`@("`@
M*3L*"B`@("`@("`@("`@(&UY("1C;VYT96YT.PH@("`@("`@("`@("!I9B`H
M<F5F*"1F:6QE*2D@>PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`D9FEL
M92T^>V)U9GT["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@
M("`@("`@("`@("`@("!O<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#
M86XG="!O<&5N("1F:6QE.B`D(2(["B`@("`@("`@("`@("`@("!B:6YM;V1E
M*$9)3$4I.PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`\1DE,13X["B`@
M("`@("`@("`@("`@("!C;&]S92!&24Q%.PH*("`@("`@("`@("`@("`@(%!!
M4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F
M:6QE*0H@("`@("`@("`@("`@("`@("`@(&EF("$D14Y6>U!!4E]615)"051)
M37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*"B`@("`@("`@
M("`@("`@("`C($1O(&YO="!L970@6%-,;V%D97(@<&EC:R!U<"!A=71O+RH@
M9G)O;2!E;G9I<F]N;65N=`H@("`@("`@("`@("`@("`@)&-O;G1E;G0@/7X@
M<R]G;W1O("MR971R>2`K=6YL97-S("LN*B]G;W1O(')E=')Y.R\*("`@("`@
M("`@("`@("`@("`@("!I9B!L8R@D;F%M92D@97$@;&,H(EA33&]A9&5R+G!M
M(BD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&]U=',H<7$H5W)I='1E
M;B!A<R`B)&YA;64B*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H(D9)3$4B
M*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N
M86UE*2`K(#DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AS<')I;G1F*`H@
M("`@("`@("`@("`@("`@(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U
M=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"B`@("`@("`@("`@("DI.PH@("`@
M("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I
M*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H)&-O;G1E;G0I.PH@("`@("`@
M('T*("`@('T*("`@(",@?7U]"@H@("`@(R!.;W<@=W)I=&4@;W5T('1H92!0
M05(@86YD(&UA9VEC('-T<FEN9W,@>WM["B`@("`D>FEP+3YW<FET951O1FEL
M94AA;F1L92@D9F@I(&EF("1Z:7`["@H@("`@)&-A8VAE7VYA;64@/2!S=6)S
M='(@)&-A8VAE7VYA;64L(#`L(#0P.PH@("`@:68@*"$D8V%C:&5?;F%M92!A
M;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["B`@("`@("`@;7D@
M)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(
M02T^;F5W*#$I('T*("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG
M97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@('Q\
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W
M('T["@H@("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ
M4TA!(#4N,S@@86YD(#4N,SD*("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E
M=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@("!I
M9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@
M)S4N,SDG*2!["B`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&]U="P@(F(B
M*2!I9B`H)&-T>"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@
M("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["B`@
M("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@("`D
M8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@("!C;&]S92@D9F@I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D8V%C:&5?;F%M
M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64["B`@("!]"B`@
M("`D8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N
M86UE*3L*("`@("1C86-H95]N86UE("X](")#04-(12(["B`@("`D9F@M/G!R
M:6YT*"1C86-H95]N86UE*3L*("`@("1F:"T^<')I;G0H<&%C:R@G3B<L("1F
M:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PH@("`@)&9H+3YP<FEN="@B
M7&Y005(N<&U<;B(I.PH@("`@)&9H+3YC;&]S93L*("`@(&-H;6]D(#`W-34L
M("1O=70["B`@("`C('U]?0H*("`@(&5X:70["GT*(R!]?7T*"B,@4')E<&%R
M92`D<')O9VYA;64@:6YT;R!005(@9FEL92!C86-H92![>WL*>PH@("`@;&%S
M="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PH*("`@(%]F:7A?<')O9VYA
M;64H*3L*"B`@("`C($YO=R!L;V%D('1H92!005(@9FEL92!A;F0@<'5T(&ET
M(&EN=&\@4$%2.CI,:6)#86-H92![>WL*("`@(')E<75I<F4@4$%2.PH@("`@
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*"B`@("!["B`@("`@
M("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE
M("=-4U=I;C,R)SL*("`@("`@("!R97%U:7)E($9I;&4Z.D9I;F0["B`@("`@
M("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"B`@("!M>2`D>FEP(#T@
M07)C:&EV93HZ6FEP+3YN97<["B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M.PH@("`@)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D
M(3H@)$`B.PH@("`@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R
M;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@
M)$`B.PH*("`@('!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B`@("`D4$%2
M.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*"B`@("`D<75I970@/2`A
M)$5.5GM005)?1$5"54=].PH@("`@;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@
M/2`B)$5.5GM005)?5$5-4'TB*2D["@H@("`@:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"B`@
M("`@("`@9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*
M("`@("`@("`@("`@;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*("`@
M("`@("`@("`@;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64[
M"B`@("`@("`@("`@(&YE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PH@
M("`@("`@("`@("`@("`@7@H@("`@("`@("`@("`@("`@+S]S:&QI8B\*("`@
M("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PH@
M("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I
M/PH@("`@("`@("`@("`@("`@*%M>+UTK*0H@("`@("`@("`@("`@("`@)`H@
M("`@("`@("`@("!]>#L*("`@("`@("`@("`@;7D@)&5X=')A8W1?;F%M92`]
M("0Q.PH@("`@("`@("`@("!M>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^
M8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["B`@("`@
M("`@("`@(&EF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^
M=6YC;VUP<F5S<V5D4VEZ92@I*2!["B`@("`@("`@("`@("`@("!O=71S*'%Q
M*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI
M<W1S(&%T("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA
M;64B('1O("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("`@("`@)&UE;6)E
M<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PH@("`@("`@("`@
M("`@("`@8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X
M(CL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*("`@(",@?7U]"GT*
M(R!]?7T*"B,@268@=&AE<F4G<R!N;R!M86EN+G!L('1O(')U;BP@<VAO=R!U
M<V%G92![>WL*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2![
M"B`@("!D:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L
M:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;
M('!R;V=R86TN<&P@70H@("`@("`@)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=
M('-R8RYP87(*+@H@("`@)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE
M(#T@)#`@/2!S:&EF="A`05)'5BD["GT*(R!]?7T*"G-U8B!#<F5A=&50871H
M('L*("`@(&UY("@D;F%M92D@/2!`7SL*("`@(`H@("`@<F5Q=6ER92!&:6QE
M.CI"87-E;F%M93L*("`@(&UY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]
M($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*
M("`@(`H@("`@<F5Q=6ER92!&:6QE.CI0871H.PH@("`@"B`@("!&:6QE.CI0
M871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H
M(&1I97,@=VET:"!E<G)O<@I]"@IS=6(@<F5Q=6ER95]M;V1U;&5S('L*("`@
M("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G
M35-7:6XS,B<["@H@("`@<F5Q=6ER92!L:6(["B`@("!R97%U:7)E($1Y;F%,
M;V%D97(["B`@("!R97%U:7)E(&EN=&5G97(["B`@("!R97%U:7)E('-T<FEC
M=#L*("`@(')E<75I<F4@=V%R;FEN9W,["B`@("!R97%U:7)E('9A<G,["B`@
M("!R97%U:7)E($-A<G`["B`@("!R97%U:7)E($-A<G`Z.DAE879Y.PH@("`@
M<F5Q=6ER92!%<G)N;SL*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@
M("`@<F5Q=6ER92!%>'!O<G1E<CL*("`@(')E<75I<F4@1F-N=&P["B`@("!R
M97%U:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@
M("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!R
M97%U:7)E($E/.CI(86YD;&4["B`@("!R97%U:7)E($E/.CI&:6QE.PH@("`@
M<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*("`@(')E<75I<F4@07)C:&EV93HZ
M6FEP.PH@("`@<F5Q=6ER92!005(["B`@("!R97%U:7)E(%!!4CHZ2&5A=GD[
M"B`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@(')E<75I<F4@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP.PH@("`@<F5Q=6ER92!A='1R:6)U=&5S.PH@("`@979A
M;"![(')E<75I<F4@0W=D('T["B`@("!E=F%L('L@<F5Q=6ER92!7:6XS,B!]
M.PH@("`@979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["B`@("!E=F%L
M('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*("`@(&5V86P@
M>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["B`@("!E=F%L
M('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*
M?0H*(R!4:&4@0R!V97)S:6]N(&]F('1H:7,@8V]D92!A<'!E87)S(&EN(&UY
M;&1R+VUK=&UP9&ER+F,*(R!4:&ES(&-O9&4@86QS;R!L:79E<R!I;B!005(Z
M.E-E='5P5&5M<"!A<R!S971?<&%R7W1E;7!?96YV(0IS=6(@7W-E=%]P87)?
M=&5M<"!["B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.
M5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B`@("`@("`@)'!A<E]T96UP(#T@
M)#$["B`@("`@("`@<F5T=7)N.PH@("`@?0H*("`@(&9O<F5A8V@@;7D@)'!A
M=&@@*`H@("`@("`@("AM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-
M4$1)4B!414U01$E2(%1%35`@5$U0("DI+`H@("`@("`@('%W*"!#.EQ<5$5-
M4"`O=&UP("X@*0H@("`@*2!["B`@("`@("`@;F5X="!U;FQE<W,@9&5F:6YE
M9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PH@("`@("`@(&UY
M("1U<V5R;F%M93L*("`@("`@("!M>2`D<'=U:60["B`@("`@("`@(R!D;V5S
M(&YO="!W;W)K(&5V97)Y=VAE<F4Z"B`@("`@("`@979A;"![*"1P=W5I9"D@
M/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PH*("`@("`@("!I9B`H
M(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PH@("`@("`@("`@("`D
M=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*("`@("`@("!]"B`@("`@
M("`@96QS:68@*&1E9FEN960@)'!W=6ED*2!["B`@("`@("`@("`@("1U<V5R
M;F%M92`]("1P=W5I9#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@
M("`@("`@("1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%
M4GT@?'P@)U-94U1%32<["B`@("`@("`@?0H@("`@("`@("1U<V5R;F%M92`]
M?B!S+UQ7+U\O9SL*"B`@("`@("`@;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N
M9FEG>U]D96QI;7UP87(M)'5S97)N86UE(CL*("`@("`@("!M:V1I<B`D<W1M
M<&1I<BP@,#<U-3L*("`@("`@("!I9B`H(21%3E9[4$%27T-,14%.?2!A;F0@
M;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*("`@("`@("`@
M("`@;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["B`@("`@("`@("`@
M('-E96L@)&9H+"`M,3@L(#(["B`@("`@("`@("`@('-Y<W)E860@)&9H+"!M
M>2`D8G5F+"`V.PH@("`@("`@("`@("!I9B`H)&)U9B!E<2`B7#!#04-(12(I
M('L*("`@("`@("`@("`@("`@('-E96L@)&9H+"`M-3@L(#(["B`@("`@("`@
M("`@("`@("!S>7-R96%D("1F:"P@)&)U9BP@-#$["B`@("`@("`@("`@("`@
M("`D8G5F(#U^(',O7#`O+V<["B`@("`@("`@("`@("`@("`D<W1M<&1I<B`N
M/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("!M>2`D8W1X
M(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN
M97<H,2D@?0H@("`@("`@("`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E
M($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0H@("`@("`@("`@
M("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E
M<W0Z.DU$-2T^;F5W('T["@H@("`@("`@("`@("`@("`@(R!7;W)K87)O=6YD
M(&9O<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@
M("`@("`@("`@;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(
M03HZ5D524TE/3B!]('Q\(#`["B`@("`@("`@("`@("`@("!I9B`H)'-H85]V
M97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2![
M"B`@("`@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D<')O9VYA;64L
M(")B(BD@:68@*"1C='@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@96QS92!["B`@("`@("`@("`@("`@("`@("`@:68@*"1C='@@86YD
M(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@)&-T>"T^861D9FEL92@D9F@I.PH@("`@("`@("`@("`@("`@("`@("`@
M("!C;&]S92@D9F@I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I
M9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z
M("1M=&EM92`I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&-L;W-E*"1F
M:"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D14Y6
M>U!!4E]#3$5!3GT@/2`Q.PH@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O
M;F9I9WM?9&5L:6U]=&5M<"TD)"(["B`@("`@("`@?0H*("`@("`@("`D14Y6
M>U!!4E]414U0?2`]("1S=&UP9&ER.PH@("`@("`@(&UK9&ER("1S=&UP9&ER
M+"`P-S4U.PH@("`@("`@(&QA<W0["B`@("!]"@H@("`@)'!A<E]T96UP(#T@
M)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H
M+BLI+SL*?0H*<W5B(%]T96UP9FEL92!["B`@("!M>2`H)&5X="P@)&-R8RD@
M/2!`7SL*("`@(&UY("@D9F@L("1F:6QE;F%M92D["@H@("`@)&9I;&5N86UE
M(#T@(B1P87)?=&5M<"\D8W)C)&5X="(["@H@("`@:68@*"1%3E9[4$%27T-,
M14%.?2D@>PH@("`@("`@('5N;&EN:R`D9FEL96YA;64@:68@+64@)&9I;&5N
M86UE.PH@("`@("`@('!U<V@@0'1M<&9I;&4L("1F:6QE;F%M93L*("`@('T*
M("`@(&5L<V4@>PH@("`@("`@(')E='5R;B`H=6YD968L("1F:6QE;F%M92D@
M:68@*"UR("1F:6QE;F%M92D["B`@("!]"@H@("`@;W!E;B`D9F@L("<^)RP@
M)&9I;&5N86UE(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H)&9H*3L*("`@(')E
M='5R;B@D9F@L("1F:6QE;F%M92D["GT*"B,@<V%M92!C;V1E(&QI=F5S(&EN
M(%!!4CHZ4V5T=7!0<F]G;F%M93HZ<V5T7W!R;V=N86UE"G-U8B!?<V5T7W!R
M;V=N86UE('L*("`@(&EF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A
M;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PH@("`@("`@("1P
M<F]G;F%M92`]("0Q.PH@("`@?0H*("`@("1P<F]G;F%M92!\?#T@)#`["@H@
M("`@:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%
M3E9[4$%27U1%35!]*2`^/2`P*2!["B`@("`@("`@)'!R;V=N86UE(#T@<W5B
M<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L
M:6U]*2`K(#$I.PH@("`@?0H*("`@(&EF("@A)$5.5GM005)?4%)/1TY!345]
M(&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2![
M"B`@("`@("`@:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PH@
M("`@("`@("`@("!R971U<FX@:68@+7,@)&9H.PH@("`@("`@('T*("`@("`@
M("!I9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B`@("`@("`@
M("`@("1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PH@("`@("`@("`@("!R
M971U<FX["B`@("`@("`@?0H@("`@?0H*("`@(&9O<F5A8V@@;7D@)&1I<B`H
M<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*
M("`@("`@("!N97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I
M<B!E<2`D14Y6>U!!4E]414U0?3L*("`@("`@("`D9&ER(#U^(',O7%$D0V]N
M9FEG>U]D96QI;7U<120O+SL*("`@("`@("`H*"1P<F]G;F%M92`]("(D9&ER
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T
M*0H@("`@("`@("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M921#;VYF:6=[7V5X97TB.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D
M:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*("`@("`@("`@
M("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@
M?0I]"@IS=6(@7V9I>%]P<F]G;F%M92!["B`@("`D,"`]("1P<F]G;F%M92!\
M?#T@)$5.5GM005)?4%)/1TY!345].PH@("`@:68@*&EN9&5X*"1P<F]G;F%M
M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*("`@("`@("`D<')O9VYA;64@
M/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@("!]"@H@("`@(R!8
M6%@@+2!H86-K('1O(&UA:V4@4%=$('=O<FL*("`@(&UY("1P=V0@/2`H9&5F
M:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0H@("`@("`@("`@
M("`@("`@.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E
M=$-W9"@I(#H@8'!W9&`I.PH@("`@8VAO;7`H)'!W9"D["B`@("`D<')O9VYA
M;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O
M;F9I9WM?9&5L:6U]+SL*"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O
M9VYA;64["GT*"G-U8B!?<&%R7VEN:71?96YV('L*("`@(&EF("@@)$5.5GM0
M05)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*("`@("`@("!R971U<FX["B`@
M("!](&5L<V4@>PH@("`@("`@("1%3E9[4$%27TE.251)04Q)6D5$?2`](#([
M"B`@("!]"@H@("`@9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'
M($-!0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@*2!["B`@("`@("`@9&5L
M971E("1%3E9[)U!!4E\G+B1??3L*("`@('T*("`@(&9O<B`H<7<O(%1-4$1)
M4B!414U0($-,14%.($1%0E5'("\I('L*("`@("`@("`D14Y6>R=005)?)RXD
M7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=0
M05)?1TQ/0D%,7R<N)%]].PH@("`@?0H*("`@(&UY("1P87)?8VQE86X@/2`B
M7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PH*("`@(&EF("@D
M14Y6>U!!4E]414U0?2D@>PH@("`@("`@(&1E;&5T92`D14Y6>U!!4E]#3$5!
M3GT["B`@("!]"B`@("!E;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?
M0TQ%04Y]*2!["B`@("`@("`@;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE
M86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*("`@("`@("`D14Y6>U!!4E]#
M3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PH@
M("`@?0I]"@IS=6(@;W5T<R!["B`@("!R971U<FX@:68@)'%U:65T.PH@("`@
M:68@*"1L;V=F:"D@>PH@("`@("`@('!R:6YT("1L;V=F:"`B0%]<;B(["B`@
M("!]"B`@("!E;'-E('L*("`@("`@("!P<FEN="`B0%]<;B(["B`@("!]"GT*
M"G-U8B!I;FET7VEN8R!["B`@("!R97%U:7)E($-O;F9I9SL*("`@('!U<V@@
M0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@
M<7<H"B`@("`@("`@87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP
M('-I=&5L:6)E>'`*("`@("`@("!V96YD;W)A<F-H97AP('9E;F1O<FQI8F5X
M<`H@("`@*3L*?0H*(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C"B,@5&AE
M(&UA:6X@<&%C:V%G92!F;W(@<V-R:7!T(&5X96-U=&EO;@H*<&%C:V%G92!M
M86EN.PH*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?
M<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PH*9&EE('%Q*'!A<BYP;#H@
M0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F
M:6QE(&]R(&1I<F5C=&]R>5QN*0H@("`@=6YL97-S("UE("1P<F]G;F%M93L*
M"F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?
M15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PH*?3L*"B0Z.E]?15)2
M3U(@/2`D0"!I9B`D0#L*?0H*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)2
M3U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I
M9B`D.CI?7T524D]2.PH*,3L*"B-L:6YE(#$P,3(*"E]?14Y$7U\*````````
M``````#_____`````/____\``````````+!G0`"T9T``````````````````
M`````/____\```````````````#I6P```````````````````&A`````````
M````````````````````````````````````````@```0`#TQ4$`!,1!````
M`````````````+!C0`"@8T``P!5``)!!0`"08T``@&-``'!C0`!@8T``4&-`
M`$!C0``P8T``(&-````````08T```&-``/!B0`#@8D``T&)``,!B0`"P8D``
MH&)``)!B0`"`8D``<&)``&!B0`!08D``0&)``+!=0``P8D``(&)``!!B0```
M8D``\&%``.!A0`#084``P&%```````"P84``^%U``*!A0`"084``@&%``'!A
M0`!@84``4&%```````!`84``,&%``"!A0````````````!!A0```84``\&!`
M`.!@0`#08$``$&A``,!@0`"P8$``H&!``)!@0`"`8$``<&!``&!@0`!08$``
M0&!``#!@0``@8$``$&!```!@0`#P7T``X%]``-!?0`#`7T``L%]``*!?0`"0
M7T``@%]``````````````````'!?0`#P74``8%]``%!?0`!`7T``,%]``"!?
M0``07T```````)`70````````````````````````````!T````?````X!=`
M``````````````````````!(`0``'0```!\```!H*D````!_@/S___\`````
M`````#@````=````'P```*`K0`````"`_/___P``````````*````!T````?
M````P"M``````8#\____```````````@````'0```!\````X+$`````'@/S_
M__\``````````#`````=````'P```+@L0`````^`_/___P``````````,!``
M`!T````?````""Y``````(#\____```````````@````'0```!\```"P+D``
M```!@/S___\``````````"`````=````'P```#0S0````/_`_/___P``````
M````Z````!T````?````J#5``````8#\____```````````@````'0```!\`
M```,-T`````'@/S___\``````````#`@```=````'P```.@W0```````````
M`````````````````!T````?````\#=`````?X#\____``````````!`````
M'0```!\```#4.D````#_P/S___\``````````&`````=````'P```*@\0```
M``^`_/___P``````````6````!T````?````C#Y``````(#\____````````
M```@````'0```!\```#D/D`````#@/S___\``````````"@````=````'P``
M`+!`0`````.`_/___P``````````*````!T````?````D$%`````!X#\____
M```````````P````'0```!\```!X14````#_P/S___\``````````%`0```=
M````'P```%Q(0````/_`_/___P``````````Z($``!T````?````3%5`````
M?X#\____``````````!`````'0```!\```",7$``````@/S___\`````````
M`"`````=````'P```/1<0`````"`_/___P``````````*````!T````?````
ML%U`````````````````````````````'0```!\```#P74``````````````
M```````````````=````'P```/A=0````#^`_/___P``````````.````!T`
M```?````1T-#.B`H1&5B:6%N(#0N-"XU+3@I(#0N-"XU`$=#0SH@*$1E8FEA
M;B`T+C0N-2TQ,"D@-"XT+C4`00\```!G;G4``0<````$`0`N<VAS=')T86(`
M+FEN=&5R<``N;F]T92Y!0DDM=&%G`"YR96=I;F9O`"YN;W1E+F=N=2YB=6EL
M9"UI9``N9'EN86UI8P`N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S
M:6]N`"YG;G4N=F5R<VEO;E]R`"YI;FET`"YT97AT`"Y-25!3+G-T=6)S`"YF
M:6YI`"YR;V1A=&$`+F5H7V9R86UE`"YC=&]R<P`N9'1O<G,`+FIC<@`N9&%T
M82YR96PN<F\`+F1A=&$`+G)L9%]M87``+F=O=``N<V1A=&$`+F)S<P`N<&1R
M`"YC;VUM96YT`"YG;G4N871T<FEB=71E<P`N;61E8G5G+F%B:3,R````````
M```````````````````````````````````````````````````+`````0``
M``(```!4`4``5`$```T```````````````$`````````$P````<````"````
M9`%``&0!```@```````````````$`````````"$````&``!P`@```(0!0`"$
M`0``&```````````````!````!@````J````!P````(```"<`4``G`$``"0`
M``````````````0`````````/0````8````"````P`%``,`!`````0``"```
M```````$````"````$8````%`````@```,`"0`#``@``?`,```<`````````
M!`````0```!,````"P````(````\!D``/`8``,`'```(`````0````0````0
M````5`````,````"````_`U``/P-``!*!@`````````````!`````````%P`
M``#___]O`@```$840`!&%```^`````<``````````@````(```!I````_O__
M;P(```!`%4``0!4``(`````(`````@````0`````````>`````$````&````
MP!5``,`5``"0```````````````$`````````'X````!````!@```%`60`!0
M%@``P$@`````````````$`````````"$`````0````8````07T``$%\``,`$
M``````````````0`````````D`````$````&````T&-``-!C``!,````````
M```````$`````````)8````!`````@```"!D0``@9```X%\`````````````
M$`````````">`````0````(`````Q$```,0```0```````````````0`````
M````J`````$````#````!,1!``3$```(```````````````$`````````*\`
M```!`````P````S$00`,Q```"```````````````!`````````"V`````0``
M``,````4Q$$`%,0```0```````````````0`````````NP````$````#````
M&,1!`!C$```(```````````````$`````````,@````!`````P```"#$00`@
MQ```0```````````````$`````````#.`````0````,```!@Q$$`8,0```0`
M``````````````0`````````UP````$````#```0<,1!`'#$``"$`0``````
M```````0````!````-P````!`````P``$/3%00#TQ0``!```````````````
M!`````````#C````"`````,`````QD$`^,4``#`0`````````````!``````
M````Z`````$``````````````/C%``"``P`````````````$`````````.T`
M```!````,`````````!XR0``.0```````````````0````$```#V````]?__
M;P``````````L<D``!````````````````$`````````!@$```$`````````
MD````,')```````````````````!``````````$````#``````````````#!
7R0``%`$``````````````0``````````
